# -*- coding: utf-8 -*-
from __future__ import (
    absolute_import,
    division,
    generators,
    nested_scopes,
    print_function,
    unicode_literals,
    with_statement,
)

import functools
import logging
import os
import sys
from itertools import chain, islice

__DEFAULT_MH_BIN_DIR__ = os.path.join(
    "C:\\", "Program Files", "Agilent", "MassHunter", "Workstation", "Quant", "bin"
)


def get_version():
    # type: () -> str
    return "{}.{}.{}".format(
        sys.version_info.major, sys.version_info.minor, sys.version_info.micro
    )


def get_argv():
    # type: () -> list
    prefix = "MH_CONSOLE_ARGS_"
    return [
        v
        for _, v in sorted(
            (int(k[len(prefix) :]), v)
            for k, v in os.environ.items()
            if k.startswith(prefix)
        )
    ]


def is_main(file_path):
    # type: (str) -> bool
    return os.path.abspath(os.environ.get("MH_CONSOLE_ARGS_0", "")) == os.path.abspath(
        file_path
    )


def field_decorator(index, **kwargs):
    # type: (int, dict) -> callable
    """
    Decorator to mark a method as a getter for a mutable record field
    and associate it with a specific index.
    """
    assert index >= 0, "The index must be positive integer"

    def decorator(func):
        # type: (callable) -> callable
        @functools.wraps(func)
        def wrapper(*args, **kwargs):
            return func(*args, **kwargs)

        # store the field index into the wrapper
        wrapper.field_index = index
        if kwargs:
            wrapper.field_attrs = kwargs
        return wrapper

    return decorator


def add_metaclass(meta_type):
    # type: (type) -> callable
    """
    six.add_metaclass fallback
    """
    if sys.version_info.major == 2:
        return lambda t: t
    else:
        import six

        return six.add_metaclass(meta_type)


class SingletonMeta(type):
    _instances = {}

    def __call__(cls, *args, **kwargs):
        if cls not in cls._instances:
            instance = super(SingletonMeta, cls).__call__(*args, **kwargs)
            cls._instances[cls] = instance
        return cls._instances[cls]


@add_metaclass(SingletonMeta)
class Logger(logging.Logger):
    __metaclass__ = SingletonMeta

    def __init__(self, *args, **kwargs):
        super(Logger, self).__init__(*args, **kwargs)
        handler = logging.StreamHandler()
        handler.setFormatter(
            logging.Formatter(fmt="[%(levelname)s]%(name)s: %(message)s")
        )
        self.addHandler(handler)


def get_logger():
    # type: () -> Logger
    return Logger("mh-operator-legacy")


logger = get_logger()


@add_metaclass(SingletonMeta)
class GlobalState(object):
    __metaclass__ = SingletonMeta  # this is for python2

    def __init__(self):
        self.state = {}

    @property
    def LibraryAccess(self):
        return self.state["libacc"]

    @LibraryAccess.setter
    def LibraryAccess(self, obj):
        self.state["libacc"] = obj

    @property
    def UADataAccess(self):
        return self.state["uadacc"]

    @UADataAccess.setter
    def UADataAccess(self, obj):
        self.state["uadacc"] = obj


global_state = GlobalState()


class _RowData:
    _fields = []
    _values = []


class RowMeta(type):
    def __new__(cls, name, bases, dct):
        # type: (str, tuple, dict) -> type
        """
        Metaclass to automatically register fields defined with @field_decorator
        and create standard properties for them.
        """
        fields_list = [None for _, v in dct.items() if hasattr(v, "field_index")]

        new_dct = {}

        for attr_name, value in dct.items():
            if hasattr(value, "field_index"):
                index = value.field_index
                assert index < len(fields_list), "There must be skipped field index"
                fields_list[index] = attr_name

                def create_setter(idx):
                    def setter(self, value):
                        # type: (_RowData, object) -> None
                        self._values[idx] = value

                    return setter

                new_dct[attr_name] = property(value, create_setter(index))
            else:
                new_dct[attr_name] = value

        new_dct["_fields"] = tuple(fields_list)

        return super(RowMeta, cls).__new__(cls, name, bases, new_dct)


@add_metaclass(RowMeta)
class RowBase(object):
    """
    Base class for mutable record types, using RecordMeta.
    """

    __metaclass__ = RowMeta  # this is for python2
    _fields = []  # _fields is populated by the metaclass

    def __init__(self, *args, **kwargs):
        """
        Initializes the MutableRecord instance.

        Args:
            *args: Initial values for the fields in order.
            **kwargs: Initial key-values for the fields in order.
        """
        if kwargs:  # key-value init
            assert not args, "Should not mix positional and key=value format initialize"
            self._values = [kwargs.pop(k, None) for k in self._fields]
            assert not kwargs, "Unrecognize fileds {}".format(kwargs.keys())
        elif not args:  # default init
            self._values = [None] * len(self._fields)
        elif len(args) == len(self._fields) and len(args) > 1:  # tuple like init
            self._values = list(args)
        else:  # dict like init
            (arg,) = args  # must be length one or raise error
            self._values = [arg[k] for k in self._fields]

    def __len__(self):
        """Returns the number of fields."""
        return len(self._fields)

    def __iter__(self):
        """Iterates over the values like tuple."""
        return iter(self._values)

    def keys(self):
        """Works like dict keys but return iterater."""
        return iter(self._fields)

    def values(self):
        """Works like dict values but return iterater."""
        return iter(self._values)

    def items(self):
        """Iterates over (name, value) pairs."""
        for name in self._fields:
            yield (name, getattr(self, name))

    def __item__(self, index):
        """Works like dict if index is str, otherwise like tuple"""
        return self._values[
            self._fields.index(index) if isinstance(index, str) else index
        ]

    def __repr__(self):
        """Returns a string representation of the object."""
        return "<{name}: {body}{rest}>".format(
            name=type(self).__name__,
            body=" ".join(islice(("{}='{}'".format(k, v) for k, v in self.items()), 5)),
            rest=" ... " if len(self) > 5 else "",
        )


@add_metaclass(SingletonMeta)
class _DataTableBase(object):
    def __getitem__(self, row_type):
        # type: (type) -> type | _DataTableBase

        def init(obj, *args):
            assert len(args) <= 1
            obj._values = [obj.RowType(r) for r in (args[0] if args else [])]

        def getitem(obj, index):
            return obj._values[index]

        attrs = {
            k: v
            for k, v in type(self).__dict__.items()
            if not k.startswith("__")
            or k
            in (
                "__doc__",
                "__len__",
                "__iter__",
                "__repr__",
            )
        }
        attrs.update(
            __init__=init,
            __getitem__=getitem,
            RowType=row_type,
        )

        return type(
            str("{}_{}".format(type(self).__name__, row_type.__name__)),
            type(self).__bases__,
            attrs,
        )

    # Following should never be called from _DataTableBase because they will be passed to real base type
    RowType = RowBase
    _values = []  # type: list[RowBase]

    def __len__(self):
        # type: () -> int
        return len(self._values)

    def __iter__(self):
        # type: () -> iter
        return iter(self._values)

    def __repr__(self):
        # type: () -> str
        return "<{}: {} rows of {}>".format(
            type(self).__name__, len(self._values), self.RowType.__name__
        )

    def append(self, *args, **kwargs):
        return self._values.append(self.RowType(*args, **kwargs))


DataTableBase = _DataTableBase()


class DataTablesBase(object):
    def __init__(self):
        self.tables = {}

    def to_json(self):
        # type: () -> str
        import json

        class fallback_encoder(json.JSONEncoder):
            def default(self, obj):
                try:
                    return super(fallback_encoder, self).default(obj)
                except TypeError:
                    return str(obj)

        return json.dumps(
            self.tables, sort_keys=True, cls=fallback_encoder, ensure_ascii=True
        )


def table_property(table_class):
    # type: (type) -> callable
    fields = table_class.RowType._fields

    def decorator(func):
        # type: (callable) -> object
        """
        Decorator to mark a method as a getter for a data table
        """

        @functools.wraps(func)
        def getter(self):
            # type: (DataTablesBase) -> dict
            return self.tables[func.__name__]

        def setter(self, obj):
            # type: (DataTablesBase, list) -> None
            import ast

            def type_map(o):
                if type(o) is bool:
                    # .Net Bool converted to "True/False" which is invalid json
                    return o == True
                if type(o) is not str and str(o) == "":
                    # Pyton2.7 unicode string may introduce error when `str(o)`
                    return None
                return o

            values = zip(
                *[
                    tuple(type_map(r[c]) for c in fields)
                    for r in chain.from_iterable(obj)
                ]
            )

            self.tables[func.__name__] = {k: v for k, v in zip(fields, values)}

        return property(getter, setter)

    return decorator



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

# Stubs for namespace: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Dialogs2

class ControlBox:  # Class
    HasHelpButtonProperty: System.Windows.DependencyProperty  # static # readonly
    HasMaximizeButtonProperty: System.Windows.DependencyProperty  # static # readonly
    HasMinimizeButtonProperty: System.Windows.DependencyProperty  # static # readonly
    HasSysMenuProperty: System.Windows.DependencyProperty  # static # readonly

    @staticmethod
    def SetHasMaximizeButton(element: System.Windows.Window, value_: bool) -> None: ...
    @staticmethod
    def SetHasHelpButton(element: System.Windows.Window, value_: bool) -> None: ...
    @staticmethod
    def SetHasMinimizeButton(element: System.Windows.Window, value_: bool) -> None: ...
    @staticmethod
    def SetHasSysMenu(element: System.Windows.Window, value_: bool) -> None: ...
    @staticmethod
    def GetHasHelpButton(element: System.Windows.Window) -> bool: ...
    @staticmethod
    def GetHasMaximizeButton(element: System.Windows.Window) -> bool: ...
    @staticmethod
    def GetHasSysMenu(element: System.Windows.Window) -> bool: ...
    @staticmethod
    def GetHasMinimizeButton(element: System.Windows.Window) -> bool: ...

class LineStyleDialog(
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceObject,
    System.Windows.Forms.IWin32Window,
    System.Windows.Forms.Layout.IArrangedElement,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStreamInit,
    System.Windows.Forms.ISupportOleDropSource,
    System.Windows.Forms.IBindableComponent,
    System.Windows.Forms.IDropTarget,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStorage,
    System.Windows.Forms.Form,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject2,
    System.Windows.Forms.UnsafeNativeMethods.IQuickActivate,
    System.Windows.Forms.IContainerControl,
    System.Windows.Forms.UnsafeNativeMethods.IPersistPropertyBag,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceActiveObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleWindow,
    System.ComponentModel.IComponent,
    System.Windows.Forms.UnsafeNativeMethods.IOleObject,
    System.Windows.Forms.UnsafeNativeMethods.IPersist,
    System.IDisposable,
    System.ComponentModel.ISynchronizeInvoke,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleControl,
):  # Class
    def __init__(
        self,
        defaultShow: bool,
        defaultColor: System.Drawing.Color,
        defaultDashStyle: System.Drawing.Drawing2D.DashStyle,
    ) -> None: ...

    CheckBoxShowLineText: str
    Color: System.Drawing.Color
    DashStyle: System.Drawing.Drawing2D.DashStyle
    ShowLine: bool

class OpenDirectoryDialog(System.IDisposable):  # Class
    def __init__(self) -> None: ...

    AllowMultipleSelections: bool
    Directories: str  # readonly
    DirectoryMustExist: bool
    Extension: str
    FileFilter: str
    HelpFile: str
    HelpTopicId: int
    InitialDir: str
    ReadOnly: bool
    ReadOnlyCheckBox: bool
    Title: str

    def Dispose(self) -> None: ...
    def ShowDialog(self, parent: System.Windows.Forms.IWin32Window) -> bool: ...

class PaneDimensionControl(
    System.Windows.Forms.UnsafeNativeMethods.IOleControl,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceObject,
    System.Windows.Forms.IWin32Window,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStreamInit,
    System.Windows.Forms.ISupportOleDropSource,
    System.Windows.Forms.Layout.IArrangedElement,
    System.Windows.Forms.IBindableComponent,
    System.Windows.Forms.IDropTarget,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStorage,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject2,
    System.Windows.Forms.UnsafeNativeMethods.IQuickActivate,
    System.Windows.Forms.IContainerControl,
    System.Windows.Forms.UnsafeNativeMethods.IPersistPropertyBag,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceActiveObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleWindow,
    System.ComponentModel.IComponent,
    System.Windows.Forms.UnsafeNativeMethods.IOleObject,
    System.Windows.Forms.UnsafeNativeMethods.IPersist,
    System.IDisposable,
    System.ComponentModel.ISynchronizeInvoke,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject,
    System.Windows.Forms.UserControl,
):  # Class
    def __init__(self) -> None: ...

    Columns: int  # readonly
    Rows: int  # readonly

    def CalcSize(self) -> System.Drawing.Size: ...

    DimensionSelected: System.EventHandler  # Event

class PaneDimensionDialogs(
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceObject,
    System.Windows.Forms.IWin32Window,
    System.Windows.Forms.Layout.IArrangedElement,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStreamInit,
    System.Windows.Forms.ISupportOleDropSource,
    System.Windows.Forms.IBindableComponent,
    System.Windows.Forms.IDropTarget,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStorage,
    System.Windows.Forms.Form,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject2,
    System.Windows.Forms.UnsafeNativeMethods.IQuickActivate,
    System.Windows.Forms.IContainerControl,
    System.Windows.Forms.UnsafeNativeMethods.IPersistPropertyBag,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceActiveObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleWindow,
    System.ComponentModel.IComponent,
    System.Windows.Forms.UnsafeNativeMethods.IOleObject,
    System.Windows.Forms.UnsafeNativeMethods.IPersist,
    System.IDisposable,
    System.ComponentModel.ISynchronizeInvoke,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleControl,
):  # Class
    def __init__(self) -> None: ...

    Columns: int  # readonly
    Rows: int  # readonly

    DimensionSelected: System.EventHandler  # Event

class ProgressDialog(
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceObject,
    System.Windows.Forms.IWin32Window,
    System.Windows.Forms.Layout.IArrangedElement,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStreamInit,
    System.Windows.Forms.ISupportOleDropSource,
    System.Windows.Forms.IBindableComponent,
    System.Windows.Forms.IDropTarget,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStorage,
    System.Windows.Forms.Form,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject2,
    System.Windows.Forms.UnsafeNativeMethods.IQuickActivate,
    System.Windows.Forms.IContainerControl,
    System.Windows.Forms.UnsafeNativeMethods.IPersistPropertyBag,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceActiveObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleWindow,
    System.ComponentModel.IComponent,
    System.Windows.Forms.UnsafeNativeMethods.IOleObject,
    System.Windows.Forms.UnsafeNativeMethods.IPersist,
    System.IDisposable,
    System.ComponentModel.ISynchronizeInvoke,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleControl,
):  # Class
    def __init__(self) -> None: ...

    Argument: Any
    CancelButtonText: str
    CancelButtonVisible: bool
    CancellationPending: bool  # readonly
    Exception: System.Exception  # readonly
    Marquee: bool
    Message: str
    ProgressMaximum: int
    ProgressMinimum: int
    ProgressStep: int
    ProgressValue: int

    def ReportProgress(self, percent: int, state: Any) -> None: ...
    def Cancel(self) -> None: ...

    CancelButtonClick: System.EventHandler  # Event
    DoWork: System.ComponentModel.DoWorkEventHandler  # Event
    ProgressChanged: System.ComponentModel.ProgressChangedEventHandler  # Event

class ProgressWindowWPF(
    System.Windows.Markup.IQueryAmbient,
    System.Windows.Media.Composition.DUCE.IResource,
    System.Windows.Window,
    System.Windows.Markup.IHaveResources,
    System.Windows.Markup.IAddChild,
    System.Windows.Media.Animation.IAnimatable,
    System.Windows.Markup.IComponentConnector,
    System.Windows.IWindowService,
    System.Windows.IInputElement,
    System.Windows.IFrameworkInputElement,
    System.ComponentModel.ISupportInitialize,
):  # Class
    def __init__(self) -> None: ...

    CanCancel: bool
    Exception: System.Exception  # readonly
    IsIndeterminate: bool
    Marquee: bool
    Maximum: float
    Message: str
    Minimum: float
    Title: str
    Value: float

    def ButtonCancel_Click(
        self, sender: Any, e: System.Windows.RoutedEventArgs
    ) -> None: ...
    def InitializeComponent(self) -> None: ...
    def ReportProgress(self, percentProgress: int, state: Any) -> None: ...

    Cancel: System.EventHandler  # Event
    DoWork: System.ComponentModel.DoWorkEventHandler  # Event
    ProgressChanged: System.ComponentModel.ProgressChangedEventHandler  # Event
    RunWorkerCompleted: System.ComponentModel.RunWorkerCompletedEventHandler  # Event

class SystemInfoDialog(
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceObject,
    System.Windows.Forms.IWin32Window,
    System.Windows.Forms.Layout.IArrangedElement,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStreamInit,
    System.Windows.Forms.ISupportOleDropSource,
    System.Windows.Forms.IBindableComponent,
    System.Windows.Forms.IDropTarget,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStorage,
    System.Windows.Forms.Form,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject2,
    System.Windows.Forms.UnsafeNativeMethods.IQuickActivate,
    System.Windows.Forms.IContainerControl,
    System.Windows.Forms.UnsafeNativeMethods.IPersistPropertyBag,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceActiveObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleWindow,
    System.ComponentModel.IComponent,
    System.Windows.Forms.UnsafeNativeMethods.IOleObject,
    System.Windows.Forms.UnsafeNativeMethods.IPersist,
    System.IDisposable,
    System.ComponentModel.ISynchronizeInvoke,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleControl,
):  # Class
    def __init__(self) -> None: ...
    @staticmethod
    def ShowSystemInfo(parent: System.Windows.Forms.IWin32Window) -> None: ...

class SystemInfoItem:  # Class
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, fileVersionInfo: System.Diagnostics.FileVersionInfo) -> None: ...
    @overload
    def __init__(
        self,
        fileVersionInfo: System.Diagnostics.FileVersionInfo,
        assembly: System.Reflection.Assembly,
    ) -> None: ...

    AssemblyConfiguration: str  # readonly
    AssemblyCulture: str  # readonly
    AssemblyTitle: str  # readonly
    ComVisible: Optional[bool]  # readonly
    Comments: str  # readonly
    CompanyName: str  # readonly
    FileDescription: str  # readonly
    FileVersion: str  # readonly
    Guid: str  # readonly
    InternalName: str  # readonly
    IsDebug: Optional[bool]  # readonly
    IsPatched: Optional[bool]  # readonly
    IsPrivateBuild: Optional[bool]  # readonly
    IsSpecialBuild: Optional[bool]  # readonly
    Language: str  # readonly
    LegalCopyright: str  # readonly
    LegalTrademarks: str  # readonly
    Location: str  # readonly
    Name: str  # readonly
    PrivateBuild: str  # readonly
    ProductName: str  # readonly
    ProductVersion: str  # readonly
    SpecialBuild: str  # readonly

class SystemInfoItemCollection(
    System.ComponentModel.IRaiseItemChangedEvents,
    System.ComponentModel.BindingList[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Dialogs2.SystemInfoItem
    ],
    Sequence[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Dialogs2.SystemInfoItem
    ],
    System.ComponentModel.IBindingList,
    System.ComponentModel.ICancelAddNew,
    System.ComponentModel.IComponent,
    Iterable[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Dialogs2.SystemInfoItem
    ],
    List[Any],
    Iterable[Any],
    List[Agilent.MassSpectrometry.DataAnalysis.Quantitative.Dialogs2.SystemInfoItem],
    Sequence[Any],
    System.IDisposable,
):  # Class
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, container: System.ComponentModel.IContainer) -> None: ...

    SynchronizeInvoke: System.ComponentModel.ISynchronizeInvoke

    def Dispose(self) -> None: ...

class WinFormHostWindow(System.Windows.Forms.IWin32Window):  # Class
    def __init__(self, window: System.Windows.Window) -> None: ...

    Handle: System.IntPtr  # readonly



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

from . import (
    AppCommandBase,
    AppCommandContext,
    CompoundFilterType,
    InstrumentType,
    INumericCustomFormat,
    INumericFormat,
    OutlierCategories,
    OutlierColumns,
    OutlierLimitType,
    OutlierTables,
    Printing,
    PrintPlotFitType,
    QuantitationDataSet,
    TargetCompoundRowId,
)
from .Controls2 import PropertySheet
from .ScriptEngine import IronEngine, IScriptEngine
from .Toolbar import IToolbar, IToolbarsManager
from .UIScriptIF import (
    CommandEventArgs,
    IAddIn,
    IAddInManager,
    IAverageQualifierRatiosDialog,
    IAverageRetentionTimeDialog,
    IBatchDataSet,
    ICalCurvePane,
    ICalibrationAtAGlance,
    IChromatogram,
    IChromatogramInformation,
    IChromatogramInformationItem,
    IChromSpecPane,
    ICompliance,
    ICompoundGroupFilter,
    ICompoundsAtAGlance,
    IDataRow,
    IEditMethodState,
    IExportPlotParameters,
    IGridRow,
    IImpersonationContext,
    ILibrarySearchWindow,
    IMainFrame,
    IMethodDataSet,
    IMethodErrorListPane,
    IMethodTablePane,
    IMethodTasksPane,
    IMethodValidationMessage,
    IMetricsPlot,
    INumberFormat,
    IOutlier,
    IOutlierDetector,
    IOutlierInfo,
    IOutlierLimits,
    IPane,
    IReport,
    IReportTaskQueue,
    ISampleDataPane,
    IScriptEngine,
    IScriptInterface,
    IScriptPane,
    IScriptScope,
    ISelectRowsDialog,
    IShiftRetentionTimeDialog,
    ISignalInfo,
    ISpectrum,
    IStatusBar,
    IUIState,
    IWindow,
    IWorktablePane,
    NavigateChangeEventArgs,
)

# Stubs for namespace: Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIScriptIFImpls

class AddInManager(System.MarshalByRefObject, IAddInManager):  # Class
    def __init__(
        self,
        uiState: Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIScriptIFImpls.UIState,
    ) -> None: ...
    def __getitem__(self, id: str) -> IAddIn: ...
    def InitializeWorkflows(self) -> None: ...
    def Initialize(self) -> None: ...
    def Clear(self) -> None: ...
    def GetIDs(self) -> List[str]: ...

class CalibrationAtAGlance(
    IWindow,
    ICalibrationAtAGlance,
    IPane,
    System.Windows.Forms.IWin32Window,
    System.MarshalByRefObject,
):  # Class
    CanCopy: bool  # readonly
    CanDelete: bool  # readonly
    CanPaste: bool  # readonly
    CanPrint: bool  # readonly
    Handle: System.IntPtr  # readonly
    Height: int
    Location: System.Drawing.Point
    NumPaneColumnsPerPage: int  # readonly
    NumPaneRowsPerPage: int  # readonly
    Visible: bool
    Width: int

    def SetPaneDimension(self, rows: int, columns: int) -> None: ...
    def Copy(self) -> None: ...
    def GetToolbarIds(self) -> List[str]: ...
    def GetSelectedTargetCompounds(self) -> List[TargetCompoundRowId]: ...
    def Print(self, displayDialog: bool) -> None: ...
    def Close(self) -> None: ...
    def PageSetup(self) -> None: ...
    def Delete(self) -> None: ...
    def Paste(self) -> None: ...
    def Activate(self) -> None: ...
    def GetToolbar(self, id: str) -> IToolbar: ...
    def PrintPreview(self) -> None: ...
    def Show(self) -> None: ...

    Closed: System.EventHandler  # Event
    WindowCreated: System.EventHandler  # Event

class ChromatogramInformationItem(
    System.MarshalByRefObject, IChromatogramInformationItem
):  # Class
    BatchID: int  # readonly
    Color: System.Drawing.Color
    DataFileName: str  # readonly
    InstrumentName: str  # readonly
    SampleID: int  # readonly
    SampleName: str  # readonly
    ScanType: Optional[Agilent.MassSpectrometry.DataAnalysis.MSScanType]  # readonly
    Signal: ISignalInfo  # readonly
    Visible: bool
    _Item: (
        Agilent.MassHunter.Quantitative.UIModel.IChromatogramInformationItem
    )  # readonly

class ComplianceCore(System.MarshalByRefObject, ICompliance):  # Class
    AlwaysAuditTrail: bool  # readonly
    ConnectionTicket: str  # readonly
    IsActive: bool  # readonly
    IsInstalled: bool  # readonly
    IsLocal: bool  # readonly
    Name: str  # readonly
    User: str  # readonly

    def IsUserValidationRequired(self, command: str) -> bool: ...
    def SetCommandReason(self, reason: str) -> None: ...
    def Impersonate(self) -> IImpersonationContext: ...
    def IsCommandReasonRequired(self, command: str) -> bool: ...
    def CheckoutBatch(self, batchFolder: str, batchFile: str) -> None: ...
    def HasPermission(self, command: str) -> bool: ...
    @overload
    def TranslateToLocalPath(self, path: str) -> str: ...
    @overload
    def TranslateToLocalPath(self, path: str, revisionNumber: str) -> str: ...
    @overload
    def ValidateUser(
        self, user: System.Security.SecureString, password: System.Security.SecureString
    ) -> None: ...
    @overload
    def ValidateUser(self, user: str, password: str) -> None: ...
    def IsBatchCheckedoutByCurrentUser(
        self, batchFolder: str, batchFile: str
    ) -> bool: ...
    def ValidateUserEncrypted(self, user: str, encryptedPassword: str) -> None: ...
    def UndoCheckoutBatch(self, batchFolder: str, batchFile: str) -> None: ...

class CompoundGroupFilter(System.MarshalByRefObject, ICompoundGroupFilter):  # Class
    def __init__(
        self, info: Agilent.MassHunter.Quantitative.UIModel.CompoundGroupFilterInfo
    ) -> None: ...

    CompoundGroup: str  # readonly
    FilterType: CompoundFilterType  # readonly

    def GetHashCode(self) -> int: ...
    def ToString(self) -> str: ...
    def Equals(self, obj: Any) -> bool: ...

class Constants(
    Sequence[System.Collections.Generic.KeyValuePair[str, str]],
    Dict[str, str],
    Iterable[System.Collections.Generic.KeyValuePair[str, str]],
    Iterable[Any],
    System.MarshalByRefObject,
):  # Class
    def __init__(self) -> None: ...

    Count: int  # readonly
    IsReadOnly: bool  # readonly
    def __getitem__(self, key: str) -> str: ...
    def __setitem__(self, key: str, value_: str) -> None: ...
    Keys: Sequence[str]  # readonly
    Values: Sequence[str]  # readonly

    def GetEnumerator(
        self,
    ) -> Iterator[System.Collections.Generic.KeyValuePair[str, str]]: ...
    def Contains(
        self, item: System.Collections.Generic.KeyValuePair[str, str]
    ) -> bool: ...
    def CopyTo(
        self,
        array: List[System.Collections.Generic.KeyValuePair[str, str]],
        arrayIndex: int,
    ) -> None: ...
    def Add(self, key: str, value_: str) -> None: ...
    def ContainsKey(self, key: str) -> bool: ...
    def Clear(self) -> None: ...
    @overload
    def Remove(self, key: str) -> bool: ...
    @overload
    def Remove(
        self, item: System.Collections.Generic.KeyValuePair[str, str]
    ) -> bool: ...
    def TryGetValue(self, key: str, value_: str) -> bool: ...

class CustomPane(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIScriptIFImpls.PaneBase, IPane
):  # Class
    def __init__(
        self,
        uiState: Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIScriptIFImpls.UIState,
        key: str,
    ) -> None: ...

    CanCopy: bool  # readonly
    CanDelete: bool  # readonly
    CanPaste: bool  # readonly
    CanPrint: bool  # readonly

    def Copy(self) -> None: ...
    def Print(self, displayDialog: bool) -> None: ...
    def PageSetup(self) -> None: ...
    def Delete(self) -> None: ...
    def Paste(self) -> None: ...
    def PrintPreview(self) -> None: ...

class EventDispatcher:  # Class
    def __init__(self, invoke: System.ComponentModel.ISynchronizeInvoke) -> None: ...
    def Remove(
        self, sender: Any, target: System.Delegate
    ) -> (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIScriptIFImpls.EventDispatcher.EventBridge
    ): ...
    def Add(
        self, key: str, sender: Any, target: System.Delegate, convert: System.Delegate
    ) -> (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIScriptIFImpls.EventDispatcher.EventBridge
    ): ...
    def Dispose(self) -> None: ...
    def DispatchByKey(self, key: str, sender: Any, e: System.EventArgs) -> None: ...

    # Nested Types

    class EventBridge:  # Class
        def __init__(
            self,
            invoke: System.ComponentModel.ISynchronizeInvoke,
            key: str,
            sender: Any,
            target: System.Delegate,
            convert: System.Delegate,
        ) -> None: ...

        Key: str  # readonly

        def Dispatch(self, sender: Any, e: System.EventArgs) -> None: ...
        def Equals(self, sender: Any, target: System.Delegate) -> bool: ...

class ExportPlotParameters(System.MarshalByRefObject, IExportPlotParameters):  # Class
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, parameters: IExportPlotParameters) -> None: ...

    AllPanes: bool
    FilePath: str
    FitType: PrintPlotFitType
    ImageFormat: System.Drawing.Imaging.ImageFormat
    PageSize: System.Drawing.SizeF
    Zoom: float

    def Export(
        self, control: Agilent.MassSpectrometry.GUI.Plot.PlotControl
    ) -> None: ...
    def ReadFromConfiguration(self) -> None: ...
    def SaveToConfiguration(self) -> None: ...

class GridRow(System.MarshalByRefObject, IGridRow):  # Class
    BandName: str  # readonly
    def __getitem__(self, columnName: str) -> Any: ...

class ImpersonationContext(
    IImpersonationContext, System.MarshalByRefObject, System.IDisposable
):  # Class
    def Dispose(self) -> None: ...

class MethodErrorListPane(
    IMethodErrorListPane,
    IPane,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIScriptIFImpls.PaneBase,
):  # Class
    CanCopy: bool  # readonly
    CanDelete: bool  # readonly
    CanPaste: bool  # readonly
    CanPrint: bool  # readonly

    def ValidateMethod(self, alwaysShowPane: bool) -> None: ...
    def ShowMessages(self, messages: Any) -> None: ...
    def Copy(self) -> None: ...
    def Print(self, displayDialog: bool) -> None: ...
    def PageSetup(self) -> None: ...
    def Delete(self) -> None: ...
    def Paste(self) -> None: ...
    def PrintPreview(self) -> None: ...

class MethodValidationMessage(
    System.MarshalByRefObject, IMethodValidationMessage
):  # Class
    ColumnName: str  # readonly
    IsError: bool  # readonly
    IsInfo: bool  # readonly
    IsWarning: bool  # readonly
    Message: str  # readonly
    TableName: str  # readonly

    def GetRowId(self) -> List[int]: ...

class NumberFormat(System.MarshalByRefObject, INumberFormat, INumericFormat):  # Class
    def Contains(self, columnName: str) -> bool: ...
    def GetColumns(self) -> List[str]: ...
    @overload
    def SetFormat(self, column: str, format: INumericCustomFormat) -> None: ...
    @overload
    def SetFormat(self, column: str, format: str) -> None: ...
    def GetFormatString(self, columnName: str) -> str: ...
    def GetFormat(self, columnName: str) -> INumericCustomFormat: ...
    def GetColumnCategory(self, column: str) -> str: ...
    def StoreFormats(self) -> None: ...
    def NotifyFormatChange(self) -> None: ...

class OptionsDialog(
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceObject,
    System.Windows.Forms.IWin32Window,
    System.Windows.Forms.Layout.IArrangedElement,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStreamInit,
    System.Windows.Forms.ISupportOleDropSource,
    System.Windows.Forms.IBindableComponent,
    System.Windows.Forms.IDropTarget,
    PropertySheet,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStorage,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject2,
    System.Windows.Forms.UnsafeNativeMethods.IQuickActivate,
    System.Windows.Forms.IContainerControl,
    System.Windows.Forms.UnsafeNativeMethods.IPersistPropertyBag,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceActiveObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleWindow,
    System.ComponentModel.IComponent,
    System.Windows.Forms.UnsafeNativeMethods.IOleObject,
    System.Windows.Forms.UnsafeNativeMethods.IPersist,
    System.IDisposable,
    System.ComponentModel.ISynchronizeInvoke,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleControl,
):  # Class
    def __init__(self) -> None: ...

class Outlier(System.MarshalByRefObject, IOutlier):  # Class
    Category: OutlierCategories  # readonly
    Column: OutlierColumns  # readonly
    FlagColumn: str  # readonly
    IsAvailable: bool  # readonly
    Table: OutlierTables  # readonly
    ValueColumn: str  # readonly

    def GetPrerequisiteColumns(self) -> List[str]: ...
    def GetOutlierInfo(self, row: IDataRow) -> IOutlierInfo: ...

class OutlierDetector(System.MarshalByRefObject, IOutlierDetector):  # Class
    def GetOutlier(self, outlierType: OutlierColumns) -> IOutlier: ...

class OutlierInfo(System.MarshalByRefObject, IOutlierInfo):  # Class
    Deteil: str  # readonly
    LimitType: OutlierLimitType  # readonly
    Limits: IOutlierLimits  # readonly
    Message: str  # readonly
    Name: str  # readonly
    Value: Any  # readonly

class OutlierLimits(System.MarshalByRefObject, IOutlierLimits):  # Class
    def __init__(
        self, r: Agilent.MassSpectrometry.DataAnalysis.MinMaxRange
    ) -> None: ...

    Max: float  # readonly
    Min: float  # readonly

class OutlierNavigatorControl(
    System.Windows.Forms.UnsafeNativeMethods.IOleControl,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceObject,
    System.Windows.Forms.IWin32Window,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStreamInit,
    System.Windows.Forms.ISupportOleDropSource,
    System.Windows.Forms.Layout.IArrangedElement,
    System.Windows.Forms.IBindableComponent,
    System.Windows.Forms.IDropTarget,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStorage,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject2,
    System.Windows.Forms.UnsafeNativeMethods.IQuickActivate,
    System.Windows.Forms.IContainerControl,
    System.Windows.Forms.UnsafeNativeMethods.IPersistPropertyBag,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceActiveObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleWindow,
    System.ComponentModel.IComponent,
    System.Windows.Forms.UnsafeNativeMethods.IOleObject,
    System.Windows.Forms.UnsafeNativeMethods.IPersist,
    System.IDisposable,
    System.ComponentModel.ISynchronizeInvoke,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject,
    System.Windows.Forms.UserControl,
):  # Class
    def __init__(self) -> None: ...

class OutlierNavigatorDialog(
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceObject,
    System.Windows.Forms.IWin32Window,
    System.Windows.Forms.Layout.IArrangedElement,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStreamInit,
    System.Windows.Forms.ISupportOleDropSource,
    System.Windows.Forms.IBindableComponent,
    System.Windows.Forms.IDropTarget,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStorage,
    System.Windows.Forms.Form,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject2,
    System.Windows.Forms.UnsafeNativeMethods.IQuickActivate,
    System.Windows.Forms.IContainerControl,
    System.Windows.Forms.UnsafeNativeMethods.IPersistPropertyBag,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceActiveObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleWindow,
    System.ComponentModel.IComponent,
    System.Windows.Forms.UnsafeNativeMethods.IOleObject,
    System.Windows.Forms.UnsafeNativeMethods.IPersist,
    System.IDisposable,
    System.ComponentModel.ISynchronizeInvoke,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleControl,
):  # Class
    def __init__(self) -> None: ...
    def Initialize(
        self,
        navigator: Agilent.MassHunter.Quantitative.UIModel.IDataNavigator,
        flagFilterManager: Agilent.MassHunter.Quantitative.UIModel.IFlagFilterManager,
    ) -> None: ...

class PaneBase(System.MarshalByRefObject, IPane):  # Class
    CanCopy: bool  # readonly
    CanDelete: bool  # readonly
    CanPaste: bool  # readonly
    CanPrint: bool  # readonly
    Visible: bool

    def Copy(self) -> None: ...
    def GetToolbarIds(self) -> List[str]: ...
    def Print(self, displayDialog: bool) -> None: ...
    def PageSetup(self) -> None: ...
    def Delete(self) -> None: ...
    def Paste(self) -> None: ...
    def GetToolbar(self, id: str) -> IToolbar: ...
    def Activate(self) -> None: ...
    def PrintPreview(self) -> None: ...

class Report(System.IDisposable, IReport):  # Class
    def Dispose(self) -> None: ...
    def QuickReport(self, templateFile: str, outputFile: str) -> None: ...

class ScriptEngine(
    IScriptEngine, System.MarshalByRefObject, System.IDisposable
):  # Class
    CurrentScope: IScriptScope  # readonly
    DebugMode: bool  # readonly
    Engine: IScriptEngine  # readonly
    Globals: IScriptScope  # readonly

    def CreateScope(self) -> IScriptScope: ...
    @overload
    def Execute(
        self,
        reader: System.IO.TextReader,
        encoding: System.Text.Encoding,
        scope: IScriptScope,
    ) -> Any: ...
    @overload
    def Execute(
        self,
        stream: System.IO.Stream,
        encoding: System.Text.Encoding,
        scope: IScriptScope,
    ) -> Any: ...
    @staticmethod
    def SetDebugEngine(
        engine: IronEngine, initEngine: System.Action[IronEngine, Any]
    ) -> None: ...
    def Dispose(self) -> None: ...
    def ExecuteFile(self, file: str, scope: IScriptScope) -> Any: ...

class ScriptInterface(System.MarshalByRefObject, IScriptInterface):  # Class
    BatchDataSet: IBatchDataSet  # readonly
    Compliance: ICompliance  # readonly
    MethodDataSet: IMethodDataSet  # readonly
    OutlierDetector: IOutlierDetector  # readonly
    ReportTaskQueue: IReportTaskQueue  # readonly
    ScriptEngine: IScriptEngine  # readonly
    UIState: IUIState  # readonly
    _ScriptInterface: IScriptInterface  # readonly

    def _WritePrivateProfileString(
        self, section: str, key: str, value_: str, fileName: str
    ) -> int: ...
    def PreCommandSetReason(self, reason: str) -> None: ...
    def _GetPrivateProfileString(
        self, section: str, key: str, defaultValue: str, fileName: str
    ) -> str: ...
    def PreCommandValidateUserEncrypted(
        self, user: str, encryptedPassword: str
    ) -> None: ...
    @overload
    def PreCommandValidateUser(self, user: str, password: str) -> None: ...
    @overload
    def PreCommandValidateUser(
        self, user: System.Security.SecureString, password: System.Security.SecureString
    ) -> None: ...

class ScriptPane(
    IPane,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIScriptIFImpls.PaneBase,
    IScriptPane,
):  # Class
    CanCopy: bool  # readonly
    CanDelete: bool  # readonly
    CanPaste: bool  # readonly
    CanPrint: bool  # readonly

    def Copy(self) -> None: ...
    def Clear(self) -> None: ...
    def Print(self, displayDialog: bool) -> None: ...
    def PageSetup(self) -> None: ...
    def Delete(self) -> None: ...
    def Paste(self) -> None: ...
    def PrintPreview(self) -> None: ...
    def Run(self) -> None: ...

class SignalInfo(
    System.MarshalByRefObject, System.IComparable[ISignalInfo], ISignalInfo
):  # Class
    DeviceName: str  # readonly
    IsMS: bool  # readonly
    OrdinalNumber: int  # readonly
    SignalName: str  # readonly

    def GetHashCode(self) -> int: ...
    def ToString(self) -> str: ...
    def Compare(
        self,
        signal: Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIScriptIFImpls.SignalInfo,
    ) -> int: ...
    def Equals(self, obj: Any) -> bool: ...

class UIState(System.MarshalByRefObject, IUIState):  # Class
    def __init__(
        self, form: Agilent.MassHunter.Quantitative.UIModel.IMainWindow
    ) -> None: ...

    ActivePane: IPane  # readonly
    ActiveWindow: System.Windows.Forms.IWin32Window  # readonly
    AddIns: IAddInManager  # readonly
    ApplicationPath: str  # readonly
    ApplicationType: str  # readonly
    BatchDataSet: IBatchDataSet  # readonly
    BatchDirectory: str  # readonly
    BatchFileName: str  # readonly
    BuildNumber: str  # readonly
    CalCurvePane: ICalCurvePane  # readonly
    CalibrationAtAGlanceView: ICalibrationAtAGlance  # readonly
    CanEditMethod: bool  # readonly
    CanRedo: bool  # readonly
    CanUndo: bool  # readonly
    ChromSpecPane: IChromSpecPane  # readonly
    ChromatogramInformationView: IChromatogramInformation  # readonly
    CompoundsAtAGlanceView: ICompoundsAtAGlance  # readonly
    Constants: Dict[str, str]  # readonly
    CurrentBatchId: int  # readonly
    CurrentCompoundId: int  # readonly
    CurrentIstdCompoundId: int  # readonly
    CurrentIstdCompoundName: str  # readonly
    CurrentLevelId: int  # readonly
    CurrentPeakId: int  # readonly
    CurrentQualifierId: int  # readonly
    CurrentSampleId: int  # readonly
    CurrentVersion: str  # readonly
    CustomerHome: str  # readonly
    DataNavigator: Agilent.MassHunter.Quantitative.UIModel.IDataNavigator  # readonly
    EditMethodState: IEditMethodState  # readonly
    EditingMethod: bool  # readonly
    HasBatch: bool  # readonly
    HasIstd: bool  # readonly
    InstrumentType: InstrumentType  # readonly
    IsAuditTrailing: bool  # readonly
    IsBatchDirty: bool  # readonly
    IsCommandRunning: bool  # readonly
    IsCurrentSampleValid: bool  # readonly
    IsCurrentTargetCompoundValid: bool  # readonly
    IsInCommandGroup: bool  # readonly
    LibrarySearchWindow: ILibrarySearchWindow  # readonly
    MainFrame: IMainFrame  # readonly
    MethodDataSet: IMethodDataSet  # readonly
    MethodErrorListPane: IMethodErrorListPane  # readonly
    MethodTablePane: IMethodTablePane  # readonly
    MethodTasksPane: IMethodTasksPane  # readonly
    MetricsPlot: IMetricsPlot  # readonly
    NumericFormat: INumberFormat  # readonly
    Report: IReport  # readonly
    SampleDataPane: ISampleDataPane  # readonly
    ScriptInterface: IScriptInterface  # readonly
    ScriptPane: IScriptPane  # readonly
    StatusBar: IStatusBar  # readonly
    SynchronizeInvoke: System.ComponentModel.ISynchronizeInvoke  # readonly
    ToolbarsManager: IToolbarsManager  # readonly
    Workflows: IAddInManager  # readonly
    WorktablePane: IWorktablePane  # readonly
    _AppCommandContext: AppCommandContext  # readonly
    _BatchDataSet: QuantitationDataSet  # readonly
    _DataNavigator: Agilent.MassHunter.Quantitative.UIModel.IDataNavigator  # readonly
    _MainForm: Agilent.MassHunter.Quantitative.UIModel.IMainWindow  # readonly
    _MethodDataSet: QuantitationDataSet  # readonly

    def CreateSelectRowsDialog(self) -> ISelectRowsDialog: ...
    def GetTargetCompoundChromatogram(self) -> IChromatogram: ...
    def Undo(self) -> None: ...
    def AddRecentBatch(self, batchPath: str, batchFile: str) -> None: ...
    def ShowAboutBox(self) -> None: ...
    def Redo(self) -> None: ...
    def GetCurrentTargetCompoundRow(self) -> IDataRow: ...
    def CreateChromatogramInformationWindow(
        self,
    ) -> Agilent.MassHunter.Quantitative.UIModel.IChromatogramInformationWindow: ...
    def CreateShiftRetentionTimeDialog(self) -> IShiftRetentionTimeDialog: ...
    def GetTargetCompoundSpectrum(self) -> ISpectrum: ...
    def CreateAverageQualifierRatiosDialog(self) -> IAverageQualifierRatiosDialog: ...
    def NavigateCompound(self, compoundId: int) -> None: ...
    def ShowExceptionMessage(self, e: System.Exception) -> None: ...
    def CleanAddIns(self) -> None: ...
    def CreateCagWindow(self) -> Agilent.MassHunter.Quantitative.UIModel.ICagWindow: ...
    @overload
    def GetTIC(self) -> IChromatogram: ...
    @overload
    def GetTIC(
        self,
        msLevel: Agilent.MassSpectrometry.DataAnalysis.MSLevel,
        scanTypes: Agilent.MassSpectrometry.DataAnalysis.MSScanType,
        minRT: float,
        maxRT: float,
    ) -> IChromatogram: ...
    def Dispose(self) -> None: ...
    def EndRunScript(self, result: System.IAsyncResult) -> Any: ...
    def GetIstdCompoundChromatogram(self) -> IChromatogram: ...
    def BeginCommandGroup(self) -> None: ...
    @overload
    @staticmethod
    def ExecuteCommandWithProgressDialog(
        commandType: System.Type, parameters: List[Any]
    ) -> Any: ...
    @overload
    @staticmethod
    def ExecuteCommandWithProgressDialog(
        parent: System.Windows.Forms.IWin32Window,
        commandType: System.Type,
        parameters: List[Any],
    ) -> Any: ...
    @overload
    @staticmethod
    def ExecuteCommandWithProgressDialog(
        state: Agilent.MassHunter.Quantitative.UIModel.IPresentationState,
        parent: System.Windows.Forms.IWin32Window,
        command: AppCommandBase,
    ) -> Any: ...
    def SetConstant(self, key: str, value_: str) -> None: ...
    def GetCompoundSpectrum(self, sampleId: int, compoundId: int) -> ISpectrum: ...
    def ShowAuditTrailView(self) -> None: ...
    def GetIstdCompoundSpectrum(self) -> ISpectrum: ...
    def ClearRecentBatches(self) -> None: ...
    def SaveGraphicsSettingsTo(self, file: str) -> None: ...
    def GetRecentBatches(self) -> List[str]: ...
    def GetCompoundChromatogram(
        self, sampleId: int, compoundId: int
    ) -> IChromatogram: ...
    def CreateAverageRetentionTimeDialogs(self) -> IAverageRetentionTimeDialog: ...
    def NavigateSample(self, sampleId: int) -> None: ...
    def InitAddIns(self) -> None: ...
    def ExceptionAbort(self, e: System.Exception) -> None: ...
    def GetCurrentSampleRow(self) -> IDataRow: ...
    def GetReferenceLibrarySpectrum(self) -> ISpectrum: ...
    def CreateCalibrationAtAGlanceWindow(
        self,
    ) -> Agilent.MassHunter.Quantitative.UIModel.ICalibrationAtAGlanceWindow: ...
    def BeginRunScript(
        self, stream: System.IO.Stream, callback: System.AsyncCallback, asyncState: Any
    ) -> System.IAsyncResult: ...
    def GetPane(self, paneId: str) -> IPane: ...
    def GetQualifierChromatogram(
        self, sampleId: int, compoundId: int, qualifierId: int
    ) -> IChromatogram: ...
    def SaveConfiguration(self) -> None: ...
    def GetTargetCompoundSpectrumForReferenceLibraryMatch(self) -> ISpectrum: ...
    def CloseMainForm(self) -> None: ...
    @overload
    @staticmethod
    def ExecuteCommand(
        parent: System.Windows.Forms.IWin32Window,
        commandType: System.Type,
        parameters: List[Any],
    ) -> Any: ...
    @overload
    @staticmethod
    def ExecuteCommand(
        state: Agilent.MassHunter.Quantitative.UIModel.IPresentationState,
        parent: System.Windows.Forms.IWin32Window,
        cmd: AppCommandBase,
    ) -> Any: ...
    def PerformCompliancePreCommand(
        self, parent: System.Windows.Forms.IWin32Window, commandName: str, action: str
    ) -> bool: ...
    def RunScript(self, file: str) -> Any: ...
    def ShowMessage(
        self,
        message: str,
        caption: str,
        buttons: System.Windows.Forms.MessageBoxButtons,
        icon: System.Windows.Forms.MessageBoxIcon,
    ) -> System.Windows.Forms.DialogResult: ...
    def EndCommandGroup(self) -> None: ...

    CommandEnd: System.EventHandler[CommandEventArgs]  # Event
    CommandGroupEnded: System.EventHandler  # Event
    CommandGroupStarted: System.EventHandler  # Event
    CommandStart: System.EventHandler[CommandEventArgs]  # Event
    NavigateChanged: System.EventHandler[NavigateChangeEventArgs]  # Event



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

from .Commands import AppContext

# Stubs for namespace: Agilent.MassSpectrometry.DataAnalysis.LibraryEdit.Remoting

class Client(System.MarshalByRefObject, System.IDisposable):  # Class
    def __init__(
        self,
        compliance: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Compliance.ICompliance,
    ) -> None: ...
    def CloseApplication(self, force: bool) -> None: ...
    def OpenProgressDialog(
        self, title: str, message: str, dowork: System.ComponentModel.DoWorkEventHandler
    ) -> None: ...
    def PrepareNewLibrary(self, library: str) -> bool: ...
    def DoWork(
        self,
        p: Agilent.MassSpectrometry.DataAnalysis.LibraryEdit.Remoting.DoWorkParameters,
    ) -> None: ...
    def SetLibraryProperty(self, properties: Dict[str, Any]) -> None: ...
    def SynthesizeSpectra(
        self, compoundId: int, spectrumProperties: Dict[str, Any], species: str
    ) -> None: ...
    def CloseProgressDialog(self) -> None: ...
    def PrepareImporting(self, isNewLibrary: bool) -> bool: ...
    def Connect(self) -> None: ...
    def Dispose(self) -> None: ...
    def ReportProgress(self, percent: int, message: str) -> None: ...
    def NewCompound(
        self, compoundProperties: Dict[str, Any], spectrumProperties: Dict[str, Any]
    ) -> int: ...
    def SaveLibrary(self) -> None: ...

class DoWorkParameters:  # Class
    def __init__(self, argument: Any) -> None: ...

    Argument: Any
    Cancel: bool
    Result: Any

class ImportDialog(
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceObject,
    System.Windows.Forms.IWin32Window,
    System.Windows.Forms.Layout.IArrangedElement,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStreamInit,
    System.Windows.Forms.ISupportOleDropSource,
    System.Windows.Forms.IBindableComponent,
    System.Windows.Forms.IDropTarget,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStorage,
    System.Windows.Forms.Form,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject2,
    System.Windows.Forms.UnsafeNativeMethods.IQuickActivate,
    System.Windows.Forms.IContainerControl,
    System.Windows.Forms.UnsafeNativeMethods.IPersistPropertyBag,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceActiveObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleWindow,
    System.ComponentModel.IComponent,
    System.Windows.Forms.UnsafeNativeMethods.IOleObject,
    System.Windows.Forms.UnsafeNativeMethods.IPersist,
    System.IDisposable,
    System.ComponentModel.ISynchronizeInvoke,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleControl,
):  # Class
    def __init__(self, context: AppContext) -> None: ...

    CurrentLibrary: bool
    ExistingLibrary: bool
    NewLibrary: bool

class Server(System.MarshalByRefObject, System.IDisposable):  # Class
    def CloseApplication(self, force: bool) -> None: ...
    def Ready(self) -> None: ...
    def OpenProgressDialog(self, title: str, message: str) -> None: ...
    def PrepareNewLibrary(self, path: str) -> bool: ...
    def SetCulture(self, ci: System.Globalization.CultureInfo) -> None: ...
    def SetLibraryProperty(self, properties: Dict[str, Any]) -> None: ...
    def SynthesizeSpectra(
        self, compoundId: int, spectrumProperties: Dict[str, Any], species: str
    ) -> None: ...
    def CloseProgressDialog(self) -> None: ...
    def PrepareImporting(self, isNewLibrary: bool) -> bool: ...
    def Dispose(self) -> None: ...
    def ReportProgress(self, percent: int, message: str) -> None: ...
    def NewCompound(
        self, compoundProperties: Dict[str, Any], spectrumProperties: Dict[str, Any]
    ) -> int: ...
    def SaveLibrary(self) -> None: ...



import logging
import sys

from ..legacy.common import SingletonMeta


class PackageLogger(metaclass=SingletonMeta):
    _logger: logging.Logger

    def __init__(self, name="mh-operator", level=logging.INFO):
        self._logger = logging.getLogger(name)
        self._logger.setLevel(level)

        handler = logging.StreamHandler(sys.stdout)
        log_format = "%(levelname)-8s %(name)s:%(lineno)d %(message)s"
        if hasattr(sys.stdout, "isatty") and sys.stdout.isatty():
            try:
                import colorlog

                formatter = colorlog.ColoredFormatter(
                    "%(log_color)s" + log_format,
                    log_colors={
                        "DEBUG": "cyan",
                        "INFO": "green",
                        "WARNING": "yellow",
                        "ERROR": "red",
                        "CRITICAL": "bold_red",
                    },
                    reset=True,
                    style="%",
                )
            except ImportError:
                formatter = logging.Formatter(log_format, style="%")
        else:
            formatter = logging.Formatter(log_format, style="%")

        handler.setFormatter(formatter)
        self._logger.addHandler(handler)
        self._logger.propagate = False

    def get_logger(self):
        return self._logger

    def set_level(self, level: str):
        self._logger.setLevel(level.upper())


def get_logger():
    return PackageLogger().get_logger()


logger = get_logger()


def set_logger_level(level):
    PackageLogger().set_level(level)



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

# Stubs for namespace: Agilent.OpenLab.Framework.DataAccess.AcamlInfrastructure.Utilities.AcamlFixes

class ChangeSignalTypeForEZChromSpectraAcamlFix(
    Agilent.OpenLab.Framework.DataAccess.AcamlInfrastructure.Interfaces.IAcamlFix
):  # Class
    def __init__(self) -> None: ...

    OrderNumber: int  # readonly

    def NeedsFix(
        self,
        pathHelper: Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.IPathHelper,
        acaml: Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.IACAML,
    ) -> bool: ...
    def Apply(
        self,
        pathHelper: Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.IPathHelper,
        acaml: Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.IACAML,
    ) -> bool: ...

class ConsolidateMethodDefinitionsAcamlFix(
    Agilent.OpenLab.Framework.DataAccess.AcamlInfrastructure.Interfaces.IAcamlFix
):  # Class
    def __init__(self) -> None: ...

    OrderNumber: int  # readonly

    def NeedsFix(
        self,
        pathHelper: Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.IPathHelper,
        acaml: Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.IACAML,
    ) -> bool: ...
    def Apply(
        self,
        pathHelper: Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.IPathHelper,
        acaml: Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.IACAML,
    ) -> bool: ...

class CreateRunTypesAcamlFix(
    Agilent.OpenLab.Framework.DataAccess.AcamlInfrastructure.Interfaces.IAcamlFix
):  # Class
    def __init__(self) -> None: ...

    OrderNumber: int  # readonly

    def NeedsFix(
        self,
        pathHelper: Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.IPathHelper,
        acaml: Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.IACAML,
    ) -> bool: ...
    def Apply(
        self,
        pathHelper: Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.IPathHelper,
        acaml: Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.IACAML,
    ) -> bool: ...

class DataFileReferencePathAcamlFix(
    Agilent.OpenLab.Framework.DataAccess.AcamlInfrastructure.Interfaces.IAcamlFix
):  # Class
    def __init__(self) -> None: ...

    OrderNumber: int  # readonly

    def NeedsFix(
        self,
        pathHelper: Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.IPathHelper,
        acaml: Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.IACAML,
    ) -> bool: ...
    def Apply(
        self,
        pathHelper: Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.IPathHelper,
        acaml: Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.IACAML,
    ) -> bool: ...

class EZChromBaselineCalculationAcamlFix(
    Agilent.OpenLab.Framework.DataAccess.AcamlInfrastructure.Interfaces.IAcamlFix
):  # Class
    def __init__(self) -> None: ...

    OrderNumber: int  # readonly

    def NeedsFix(
        self,
        pathHelper: Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.IPathHelper,
        acaml: Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.IACAML,
    ) -> bool: ...
    def Apply(
        self,
        pathHelper: Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.IPathHelper,
        acaml: Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.IACAML,
    ) -> bool: ...

class InternalStandardAmountIdentifierAcamlFix(
    Agilent.OpenLab.Framework.DataAccess.AcamlInfrastructure.Interfaces.IAcamlFix
):  # Class
    def __init__(self) -> None: ...

    OrderNumber: int  # readonly

    def NeedsFix(
        self,
        pathHelper: Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.IPathHelper,
        acaml: Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.IACAML,
    ) -> bool: ...
    def Apply(
        self,
        pathHelper: Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.IPathHelper,
        acaml: Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.IACAML,
    ) -> bool: ...

class ScalePeaksAcamlFix(
    Agilent.OpenLab.Framework.DataAccess.AcamlInfrastructure.Interfaces.IAcamlFix
):  # Class
    def __init__(self) -> None: ...

    OrderNumber: int  # readonly

    def NeedsFix(
        self,
        pathHelper: Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.IPathHelper,
        acaml: Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.IACAML,
    ) -> bool: ...
    def Apply(
        self,
        pathHelper: Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.IPathHelper,
        acaml: Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.IACAML,
    ) -> bool: ...

class UndefinedBaselineAcamlFix(
    Agilent.OpenLab.Framework.DataAccess.AcamlInfrastructure.Interfaces.IAcamlFix
):  # Class
    def __init__(self) -> None: ...

    OrderNumber: int  # readonly

    def NeedsFix(
        self,
        pathHelper: Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.IPathHelper,
        acaml: Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.IACAML,
    ) -> bool: ...
    def Apply(
        self,
        pathHelper: Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.IPathHelper,
        acaml: Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.IACAML,
    ) -> bool: ...



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

from .Tools import (
    IApplicationMenu2010,
    IApplicationMenu2010Item,
    IContextMenu,
    IGroup,
    IMenu,
    ITabItem,
    ITool,
    IToolbar,
)
from .ViewModel import ICustomizeRibbonViewModel, IWindowTargetViewModel

# Stubs for namespace: Agilent.MassHunter.Quantitative.Startup.Edit.Ribbon.PropertyView

class ApplicationMenuItemViewModel(
    Agilent.MassHunter.Quantitative.Startup.Edit.Ribbon.PropertyView.ToolViewModel,
    System.ComponentModel.INotifyPropertyChanged,
):  # Class
    def __init__(
        self, model: IWindowTargetViewModel, item: IApplicationMenu2010Item
    ) -> None: ...

    Title: str  # readonly

class ApplicationMenuViewModel(
    Agilent.MassHunter.Quantitative.Startup.Edit.Ribbon.PropertyView.ToolViewModel,
    System.ComponentModel.INotifyPropertyChanged,
):  # Class
    def __init__(
        self, model: IWindowTargetViewModel, am: IApplicationMenu2010
    ) -> None: ...

    Title: str  # readonly

class ButtonView(
    System.Windows.Media.Composition.DUCE.IResource,
    System.Windows.Media.Animation.IAnimatable,
    System.Windows.Controls.UserControl,
    System.Windows.IInputElement,
    System.Windows.Markup.IHaveResources,
    System.Windows.Markup.IComponentConnector,
    System.Windows.IFrameworkInputElement,
    System.ComponentModel.ISupportInitialize,
    System.Windows.Markup.IQueryAmbient,
    System.Windows.Markup.IAddChild,
):  # Class
    def __init__(self) -> None: ...
    def InitializeComponent(self) -> None: ...

class ButtonViewModel(
    Agilent.MassHunter.Quantitative.Startup.Edit.Ribbon.PropertyView.ToolViewModel,
    System.ComponentModel.INotifyPropertyChanged,
):  # Class
    def __init__(self, model: IWindowTargetViewModel, tool: ITool) -> None: ...

    BrowseLargeImage: System.Windows.Input.ICommand  # readonly
    BrowseSmallImage: System.Windows.Input.ICommand  # readonly
    MaximumSize: Optional[Infragistics.Windows.Ribbon.RibbonToolSizingMode]
    MaximumSizeItems: List[Any]  # readonly
    MenuTypeVisibility: System.Windows.Visibility  # readonly
    MinimumSize: Optional[Infragistics.Windows.Ribbon.RibbonToolSizingMode]
    ScriptExecute: str
    ScriptModule: str
    ScriptSetState: str
    Title: str  # readonly

    def DoDefault(self) -> None: ...
    def DoOK(self) -> None: ...

class ChooseImageWindow(
    System.Windows.Markup.IQueryAmbient,
    System.Windows.Media.Composition.DUCE.IResource,
    System.Windows.Window,
    System.Windows.Markup.IHaveResources,
    System.Windows.Markup.IAddChild,
    System.Windows.Media.Animation.IAnimatable,
    System.Windows.Markup.IComponentConnector,
    System.Windows.IWindowService,
    System.Windows.IInputElement,
    System.Windows.IFrameworkInputElement,
    System.ComponentModel.ISupportInitialize,
):  # Class
    def __init__(self) -> None: ...

    SelectedImage: str

    def InitializeComponent(self) -> None: ...

class ChooseImageWindowModel(System.Windows.DependencyObject):  # Class
    def __init__(self) -> None: ...

    SelectedItemProperty: System.Windows.DependencyProperty  # static # readonly

    ImageItems: List[
        Agilent.MassHunter.Quantitative.Startup.Edit.Ribbon.PropertyView.ChooseImageWindowModel.ImageItem
    ]  # readonly
    SelectedImage: str
    SelectedItem: (
        Agilent.MassHunter.Quantitative.Startup.Edit.Ribbon.PropertyView.ChooseImageWindowModel.ImageItem
    )

    # Nested Types

    class ImageItem:  # Class
        def __init__(self) -> None: ...

        Image: System.Windows.Media.ImageSource
        ImageHeight: float  # readonly
        ImageWidth: float  # readonly
        Name: str

class ContextMenuView(
    System.Windows.Media.Composition.DUCE.IResource,
    System.Windows.Media.Animation.IAnimatable,
    System.Windows.Controls.UserControl,
    System.Windows.IInputElement,
    System.Windows.Markup.IHaveResources,
    System.Windows.Markup.IComponentConnector,
    System.Windows.IFrameworkInputElement,
    System.ComponentModel.ISupportInitialize,
    System.Windows.Markup.IQueryAmbient,
    System.Windows.Markup.IAddChild,
):  # Class
    def __init__(self) -> None: ...
    def InitializeComponent(self) -> None: ...

class ContextMenuViewModel(
    Agilent.MassHunter.Quantitative.Startup.Edit.Ribbon.PropertyView.ToolViewModel,
    System.ComponentModel.INotifyPropertyChanged,
):  # Class
    def __init__(
        self, model: IWindowTargetViewModel, contextmenu: IContextMenu
    ) -> None: ...

    Title: str  # readonly
    Visible: bool

    def DoDefault(self) -> None: ...
    def DoOK(self) -> None: ...

class GroupView(
    System.Windows.Media.Composition.DUCE.IResource,
    System.Windows.Media.Animation.IAnimatable,
    System.Windows.Controls.UserControl,
    System.Windows.IInputElement,
    System.Windows.Markup.IHaveResources,
    System.Windows.Markup.IComponentConnector,
    System.Windows.IFrameworkInputElement,
    System.ComponentModel.ISupportInitialize,
    System.Windows.Markup.IQueryAmbient,
    System.Windows.Markup.IAddChild,
):  # Class
    def __init__(self) -> None: ...
    def InitializeComponent(self) -> None: ...

class GroupViewModel(
    Agilent.MassHunter.Quantitative.Startup.Edit.Ribbon.PropertyView.ToolViewModel,
    System.ComponentModel.INotifyPropertyChanged,
):  # Class
    def __init__(self, model: IWindowTargetViewModel, group: IGroup) -> None: ...

    BrowseImage: System.Windows.Input.ICommand  # readonly
    Title: str  # readonly

    def DoDefault(self) -> None: ...

class MenuViewModel(
    Agilent.MassHunter.Quantitative.Startup.Edit.Ribbon.PropertyView.ButtonViewModel,
    System.ComponentModel.INotifyPropertyChanged,
):  # Class
    def __init__(self, model: IWindowTargetViewModel, menu: IMenu) -> None: ...

    ButtonType: Infragistics.Windows.Ribbon.MenuToolButtonType
    ButtonTypeItems: List[Any]  # readonly
    MenuTypeVisibility: System.Windows.Visibility  # readonly
    Title: str  # readonly

    def DoDefault(self) -> None: ...
    def DoOK(self) -> None: ...

class PropertiesViewModel:  # Class
    def __init__(
        self,
        model: IWindowTargetViewModel,
        parentWindow: System.Windows.Window,
        tool: ITool,
    ) -> None: ...

    CancelCommand: System.Windows.Input.ICommand  # readonly
    ContentModel: Any
    DefaultCommand: System.Windows.Input.ICommand  # readonly
    OkCommand: System.Windows.Input.ICommand  # readonly

class PropertiesWindow(
    System.Windows.Markup.IQueryAmbient,
    System.Windows.Media.Composition.DUCE.IResource,
    System.Windows.Window,
    System.Windows.Markup.IHaveResources,
    System.Windows.Markup.IAddChild,
    System.Windows.Media.Animation.IAnimatable,
    System.Windows.Markup.IComponentConnector,
    System.Windows.IWindowService,
    System.Windows.IInputElement,
    System.Windows.IFrameworkInputElement,
    System.ComponentModel.ISupportInitialize,
):  # Class
    def __init__(self) -> None: ...
    def InitializeComponent(self) -> None: ...

class TabItemView(
    System.Windows.Media.Composition.DUCE.IResource,
    System.Windows.Media.Animation.IAnimatable,
    System.Windows.Controls.UserControl,
    System.Windows.IInputElement,
    System.Windows.Markup.IHaveResources,
    System.Windows.Markup.IComponentConnector,
    System.Windows.IFrameworkInputElement,
    System.ComponentModel.ISupportInitialize,
    System.Windows.Markup.IQueryAmbient,
    System.Windows.Markup.IAddChild,
):  # Class
    def __init__(self) -> None: ...
    def InitializeComponent(self) -> None: ...

class TabItemViewModel(
    Agilent.MassHunter.Quantitative.Startup.Edit.Ribbon.PropertyView.ToolViewModel,
    System.ComponentModel.INotifyPropertyChanged,
):  # Class
    def __init__(self, model: IWindowTargetViewModel, tabItem: ITabItem) -> None: ...

    Title: str  # readonly

class ToolViewModel(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIUtils2.NotifyPropertyBase,
    System.ComponentModel.INotifyPropertyChanged,
):  # Class
    def __init__(self, model: IWindowTargetViewModel, tool: ITool) -> None: ...

    Caption: str
    CustomizeRibbonViewModel: ICustomizeRibbonViewModel  # readonly
    ID: str
    IsIDReadOnly: bool  # readonly
    LargeImage: System.Windows.Media.ImageSource  # readonly
    SmallImage: System.Windows.Media.ImageSource  # readonly
    Title: str  # readonly
    Tooltip: str
    UseDefaultCaption: bool
    UseDefaultTooltip: bool
    WindowTargetViewModel: IWindowTargetViewModel  # readonly
    _LargeImage: str
    _SmallImage: str

    def DoDefault(self) -> None: ...
    def DoOK(self) -> None: ...
    @overload
    def GetCaption(
        self, tool: Agilent.MassHunter.Quantitative.ToolbarWPF.Definitions.ToolBase
    ) -> str: ...
    @overload
    def GetCaption(self, id: str) -> str: ...

class ToolbarView(
    System.Windows.Media.Composition.DUCE.IResource,
    System.Windows.Media.Animation.IAnimatable,
    System.Windows.Controls.UserControl,
    System.Windows.IInputElement,
    System.Windows.Markup.IHaveResources,
    System.Windows.Markup.IComponentConnector,
    System.Windows.IFrameworkInputElement,
    System.ComponentModel.ISupportInitialize,
    System.Windows.Markup.IQueryAmbient,
    System.Windows.Markup.IAddChild,
):  # Class
    def __init__(self) -> None: ...
    def InitializeComponent(self) -> None: ...

class ToolbarViewModel(
    Agilent.MassHunter.Quantitative.Startup.Edit.Ribbon.PropertyView.ToolViewModel,
    System.ComponentModel.INotifyPropertyChanged,
):  # Class
    def __init__(self, model: IWindowTargetViewModel, toolbar: IToolbar) -> None: ...

    Title: str  # readonly

    @overload
    def GetCaption(self, id: str) -> str: ...
    @overload
    def GetCaption(
        self, tool: Agilent.MassHunter.Quantitative.ToolbarWPF.Definitions.ToolBase
    ) -> str: ...



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

# Stubs for namespace: Agilent.OpenLab.RawData

class AcmdDoc:  # Class
    @overload
    @staticmethod
    def Save(
        metadata: Agilent.OpenLab.RawData.RawMetadata, stream: System.IO.Stream
    ) -> None: ...
    @overload
    @staticmethod
    def Save(metadata: Agilent.OpenLab.RawData.RawMetadata, filename: str) -> None: ...

class BinReader(System.IDisposable, System.IO.BinaryReader):  # Class
    def __init__(self, stream: System.IO.Stream) -> None: ...
    def ReadBigEndianInt32(self) -> int: ...
    def ReadRawBytes(self, length: int) -> List[int]: ...
    def ReadBigEndianInt16(self) -> int: ...
    def ReadBigEndianDouble(self) -> float: ...
    @overload
    def ReadLittleEndianDoubles(
        self, values: List[float], numberOfDataPoints: int
    ) -> None: ...
    @overload
    def ReadLittleEndianDoubles(
        self, values: List[float], numberOfDataPoints: int, scalingFactor: float
    ) -> None: ...
    @overload
    def ReadLittleEndianDoubles(
        self, xvalues: List[float], yvalues: List[float], numberOfDataPoints: int
    ) -> None: ...
    def ReadLittleEndianInt16(self) -> int: ...
    def ReadLittleEndianDouble(self) -> float: ...
    def ReadBigEndianFloat(self) -> float: ...
    def ReadString(self, length: int) -> str: ...
    def ReadLittleEndianInt32(self) -> int: ...

class BinWriter(System.IDisposable, System.IO.BinaryWriter):  # Class
    def __init__(self, stream: System.IO.Stream) -> None: ...
    def WriteBigEndianFloat(self, value_: float) -> None: ...
    def WriteLittleEndianInt16(self, value_: int) -> None: ...
    def WriteString(self, value_: str, lenOfField: int) -> None: ...
    def WriteBigEndianInt32(self, value_: int) -> None: ...
    def WriteFiller(self, len: int) -> None: ...
    def WriteBigEndianInt16(self, value_: int) -> None: ...
    def WriteBigEndianDouble(self, value_: float) -> None: ...
    def WriteLittleEndianInt32(self, value_: int) -> None: ...
    def WriteLittleEndianDouble(self, value_: float) -> None: ...

class ContentTypeDx:  # Class
    ContentAcquisitionMethod: str = ...  # static # readonly
    ContentInstrumentConfiguration: str = ...  # static # readonly
    DefaultMassCalXml: str = ...  # static # readonly
    GenericPart: str = ...  # static # readonly
    GenericResults: str = ...  # static # readonly
    InstrumentTrace179: str = ...  # static # readonly
    Metadata: str = ...  # static # readonly
    MsContentsXml: str = ...  # static # readonly
    MsData: str = ...  # static # readonly
    MsDevicesXml: str = ...  # static # readonly
    MsScanXsd: str = ...  # static # readonly
    MsTimeSegmentXml: str = ...  # static # readonly
    RelationshipAcquisitionMethod: str = ...  # static # readonly
    RelationshipDefaultMassCalXml: str = ...  # static # readonly
    RelationshipGenericParts: str = ...  # static # readonly
    RelationshipMetadata: str = ...  # static # readonly
    RelationshipMsContentsXml: str = ...  # static # readonly
    RelationshipMsDevicesXml: str = ...  # static # readonly
    RelationshipMsScanXsd: str = ...  # static # readonly
    RelationshipMsTimeSegmentXml: str = ...  # static # readonly
    RelationshipSpectraDirectory: str = ...  # static # readonly
    Signal179: str = ...  # static # readonly
    SignalNonEquidistant179: str = ...  # static # readonly
    Spectra131: str = ...  # static # readonly
    SpectraDirectory131: str = ...  # static # readonly

class HeaderData:  # Class
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, location: str, sequenceLine: int, replicate: int) -> None: ...

    StandardFileHeader2D: Agilent.OpenLab.RawData.StandardFileHeader2D

class IRawData(object):  # Interface
    Description: str  # readonly
    TraceId: str  # readonly

class IRawData2DNonEquidistantSignal(Agilent.OpenLab.RawData.IRawData):  # Interface
    IsIntegrable: bool  # readonly
    Slope: float  # readonly
    XUnits: Agilent.OpenLab.RawData.XUnitType  # readonly
    XValues: List[float]  # readonly
    YUnits: str  # readonly
    YValues: List[float]  # readonly

class IRawData2DSignal(Agilent.OpenLab.RawData.IRawData):  # Interface
    EndTime: float
    ExpectedEndTime: float
    IsIntegrable: bool  # readonly
    Slope: float  # readonly
    StartTime: float  # readonly
    Step: float
    XUnits: Agilent.OpenLab.RawData.XUnitType  # readonly
    YUnits: str  # readonly
    YValues: List[float]  # readonly

class IRawDataGenericResults(Agilent.OpenLab.RawData.IRawData):  # Interface
    Content: List[int]  # readonly

class IRawDataInstrumentTrace(Agilent.OpenLab.RawData.IRawData):  # Interface
    Slope: float  # readonly
    XUnits: Agilent.OpenLab.RawData.XUnitType  # readonly
    XValues: List[float]  # readonly
    YUnits: str  # readonly
    YValues: List[float]  # readonly

class IRawDataSpectra(Agilent.OpenLab.RawData.IRawData):  # Interface
    DetectorType: Agilent.OpenLab.RawData.SpectraDetectorType  # readonly
    ScaleFactor: float  # readonly
    Spectra: System.Collections.Generic.List[
        Agilent.OpenLab.RawData.LCSpectrum
    ]  # readonly
    TimeUnit: Agilent.OpenLab.RawData.TimeUnitType  # readonly
    XUnits: Agilent.OpenLab.RawData.XUnitType  # readonly
    YUnits: str  # readonly

class IWriter2DCreateInfo(Agilent.OpenLab.RawData.IWriterCreateInfo):  # Interface
    ChannelName: str
    DeviceName: str
    DeviceNumber: str
    IsIntegrable: bool
    SampleFrequency: float
    SignalDescription: str
    SignalUnits: str
    Slope: float

class IWriter3DCreateInfo(Agilent.OpenLab.RawData.IWriterCreateInfo):  # Interface
    DeviceName: str
    DeviceNumber: str
    ScaleFactor: float
    SpectraDescription: str
    Units: str

class IWriterAdd2DDataInfo(Agilent.OpenLab.RawData.IWriterAddDataInfo):  # Interface
    EndTime: float
    StartTime: Optional[float]
    YValues: List[float]

class IWriterAdd3DDataInfo(Agilent.OpenLab.RawData.IWriterAddDataInfo):  # Interface
    DetectorType: Agilent.OpenLab.RawData.SpectraDetectorType
    SpectrumRecords: System.Collections.Generic.List[Agilent.OpenLab.RawData.LCSpectrum]

class IWriterAddDataInfo(object):  # Interface
    Description: str
    TraceId: str

class IWriterAddMsDataInfo(Agilent.OpenLab.RawData.IWriterAddDataInfo):  # Interface
    IsEndOfData: bool
    ScansData: List[Agilent.OpenLab.RawData.MassSpecScan]

class IWriterCreateInfo(object):  # Interface
    Description: str
    TraceId: str

class IWriterMsCreateInfo(Agilent.OpenLab.RawData.IWriterCreateInfo):  # Interface
    Contents: Agilent.MassSpectrometry.DataAnalysis.Contents
    Device: Agilent.MassSpectrometry.DataAnalysis.Device
    MsInitializationInfo: str
    MsMassCalBinStream: System.IO.Stream
    MsPeakBinStream: System.IO.Stream
    MsProfileBinStream: System.IO.Stream
    MsScanBinStream: System.IO.Stream

class InjectionAcquisitionMetadata:  # Class
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(
        self,
        location: str,
        sequenceLine: int,
        replicate: int,
        sampleName: str,
        runOperator: str,
        barcode: str,
        runDateTime: System.DateTime,
        injectionSource: str,
        injectionVolume: float,
        injectionVolumeUnits: str,
        acquisitionMethod: str,
    ) -> None: ...

    AcquisitionMethod: str
    Barcode: str
    InjectionSource: str
    InjectionVolume: float
    InjectionVolumeUnits: str
    Location: str
    Replicate: int
    RunDateTime: System.DateTime
    RunOperator: str
    SampleName: str
    SequenceLine: int

class LCDadSpectrum(Agilent.OpenLab.RawData.LCSpectrum):  # Class
    def __init__(self) -> None: ...

    ExposureTime: float

class LCFldSpectrum(Agilent.OpenLab.RawData.LCSpectrum):  # Class
    def __init__(self) -> None: ...

    ComplementWavelength: float
    ScanSpeed: float

class LCSpectrum:  # Class
    DataPoints: List[float]
    RetentionTime: float
    SpecAttribute: Agilent.OpenLab.RawData.SpectrumAttribute
    WavelengthFrom: float
    WavelengthStep: float
    WavelengthTo: float

class MassSpecScan:  # Class
    def __init__(
        self, msScanDataStreams: List[Agilent.OpenLab.RawData.MassSpecScanData]
    ) -> None: ...

    MassSpecScanDataStreams: List[Agilent.OpenLab.RawData.MassSpecScanData]

class MassSpecScanData:  # Class
    def __init__(self, id: str, dataInfo: str, data: List[int]) -> None: ...

    Data: List[int]
    DataInfo: str
    Id: str

class PackageBase:  # Class
    def Close(self) -> None: ...
    def LoadMetadata(self) -> Agilent.OpenLab.RawData.RawMetadata: ...

class PackageReader(Agilent.OpenLab.RawData.PackageBase):  # Class
    def __init__(self, fileStream: System.IO.Stream) -> None: ...

class PackageWriter(Agilent.OpenLab.RawData.PackageBase):  # Class
    def __init__(self, fileStream: System.IO.Stream) -> None: ...

class RawData2DSignal(
    Agilent.OpenLab.RawData.IRawData2DSignal, Agilent.OpenLab.RawData.IRawData
):  # Class
    def __init__(self) -> None: ...

    Description: str
    EndTime: float
    ExpectedEndTime: float
    IsIntegrable: bool
    Slope: float
    StartTime: float
    Step: float
    TraceId: str
    XUnits: Agilent.OpenLab.RawData.XUnitType
    YUnits: str
    YValues: List[float]

class RawDataGenericResults(
    Agilent.OpenLab.RawData.IRawData, Agilent.OpenLab.RawData.IRawDataGenericResults
):  # Class
    def __init__(self) -> None: ...

    Content: List[int]
    Description: str
    TraceId: str

class RawDataInstrumentTrace(
    Agilent.OpenLab.RawData.IRawDataInstrumentTrace, Agilent.OpenLab.RawData.IRawData
):  # Class
    def __init__(self) -> None: ...

    Description: str
    Slope: float
    TraceId: str
    XUnits: Agilent.OpenLab.RawData.XUnitType
    XValues: List[float]
    YUnits: str
    YValues: List[float]

class RawDataLegacyMetadata:  # Class
    def __init__(self) -> None: ...

    AcquisitionDateTime: str
    AcquisitionMethodName: str
    Barcode: str
    Operator: str
    Replicate: int
    SampleName: str
    SeqIndex: int
    SignalDescription: str
    Vial: str

class RawDataNonEquidistantSignal(
    Agilent.OpenLab.RawData.IRawData2DNonEquidistantSignal,
    Agilent.OpenLab.RawData.IRawData,
):  # Class
    def __init__(self) -> None: ...

    Description: str
    IsIntegrable: bool
    Slope: float
    TraceId: str
    XUnits: Agilent.OpenLab.RawData.XUnitType
    XValues: List[float]
    YUnits: str
    YValues: List[float]

class RawDataReader(System.IDisposable):  # Class
    def __init__(self, fileStream: System.IO.Stream) -> None: ...

    InjectionAcquisitionMetadata: (
        Agilent.OpenLab.RawData.InjectionAcquisitionMetadata
    )  # readonly
    Signals: System.Collections.Generic.List[
        Agilent.OpenLab.RawData.SignalMetadata
    ]  # readonly

    @staticmethod
    def ReadLegacyMetadata(
        fileStream: System.IO.Stream,
    ) -> Agilent.OpenLab.RawData.RawDataLegacyMetadata: ...
    def ReadInstrumentConfiguration(self) -> System.IO.Stream: ...
    def ReadSignalMetadata(
        self, traceId: str
    ) -> Agilent.OpenLab.RawData.SignalMetadata: ...
    def Dispose(self) -> None: ...
    def ReadSignal(self, traceId: str) -> Agilent.OpenLab.RawData.IRawData: ...
    def ReadAcquisitionMethod(self) -> System.IO.Stream: ...

class RawDataSpectra(
    Agilent.OpenLab.RawData.IRawDataSpectra, Agilent.OpenLab.RawData.IRawData
):  # Class
    def __init__(self) -> None: ...

    Description: str
    DetectorType: Agilent.OpenLab.RawData.SpectraDetectorType
    ScaleFactor: float
    Spectra: System.Collections.Generic.List[Agilent.OpenLab.RawData.LCSpectrum]
    TimeUnit: Agilent.OpenLab.RawData.TimeUnitType
    TraceId: str
    XUnits: Agilent.OpenLab.RawData.XUnitType
    YUnits: str

class RawDataWriter(System.IDisposable):  # Class
    @overload
    def __init__(
        self,
        fileStream: System.IO.Stream,
        injectionAcquisitionMetadata: Agilent.OpenLab.RawData.InjectionAcquisitionMetadata,
    ) -> None: ...
    @overload
    def __init__(self, fileStream: System.IO.Stream) -> None: ...
    def AddData(
        self, addDataInfo: Agilent.OpenLab.RawData.IWriterAddDataInfo
    ) -> bool: ...
    def AddSpectraFile(
        self,
        traceId: str,
        deviceName: str,
        deviceNumber: str,
        signalDescription: str,
        scaleFactor: float,
        units: str,
        detectorType: Agilent.OpenLab.RawData.SpectraDetectorType,
        spectrumRecords: System.Collections.Generic.List[
            Agilent.OpenLab.RawData.LCSpectrum
        ],
    ) -> bool: ...
    def CreateSignal(
        self,
        traceId: str,
        deviceName: str,
        deviceNumber: str,
        channelName: str,
        sampleFrequency: float,
        signalUnits: str,
        signalDescription: str,
        slope: float,
        isIntegrable: bool,
    ) -> bool: ...
    def Add2DSignal(
        self,
        traceId: str,
        deviceName: str,
        deviceNumber: str,
        channelName: str,
        startTime: float,
        endTime: float,
        sampleFrequency: float,
        signalUnits: str,
        signalDescription: str,
        slope: float,
        isIntegrable: bool,
        valuesY: List[float],
    ) -> bool: ...
    def Dispose(self) -> None: ...
    def AddTo2DSignal(
        self,
        traceId: str,
        startTime: Optional[float],
        endTime: float,
        valuesY: List[float],
    ) -> bool: ...
    def AddToInstrumentTrace(
        self, traceId: str, valuesX: List[float], valuesY: List[float]
    ) -> bool: ...
    def CreateFile(
        self,
        injectionAcquisitionMetadata: Agilent.OpenLab.RawData.InjectionAcquisitionMetadata,
    ) -> None: ...
    def AddAcquisitionMethod(self, methodStream: System.IO.Stream) -> bool: ...
    def AppendToMsExternalElementPaths(
        self, elementPaths: str, traceId: str
    ) -> None: ...
    def CreateNonEquidistantSignal(
        self,
        traceId: str,
        deviceName: str,
        deviceNumber: str,
        channelName: str,
        signalUnits: str,
        signalDescription: str,
        slope: float,
        isIntegrable: bool,
    ) -> bool: ...
    def CreateInstrumentTrace(
        self,
        traceId: str,
        deviceName: str,
        deviceNumber: str,
        channelName: str,
        axisTitleY: str,
        description: str,
        axisMultiplierY: float,
    ) -> bool: ...
    def CreateData(
        self, createDataInfo: Agilent.OpenLab.RawData.IWriterCreateInfo
    ) -> bool: ...
    def AddGenericResults(
        self,
        traceId: str,
        moduleId: str,
        serialNumber: str,
        dataChannelId: str,
        dataChannelName: str,
        dataChannelDescription: str,
        dataContentId: str,
        dataContentSequenceNumber: str,
        dataContentType: str,
        content: List[int],
    ) -> bool: ...
    def Add2DNonEquidistantSignal(
        self,
        traceId: str,
        deviceName: str,
        deviceNumber: str,
        channelName: str,
        signalUnits: str,
        signalDescription: str,
        slope: float,
        isIntegrable: bool,
        valuesX: List[float],
        valuesY: List[float],
    ) -> bool: ...
    def AddSpectraRecords(
        self,
        traceId: str,
        detectorType: Agilent.OpenLab.RawData.SpectraDetectorType,
        spectrumRecords: System.Collections.Generic.List[
            Agilent.OpenLab.RawData.LCSpectrum
        ],
    ) -> bool: ...
    def AddInstrumentConfiguration(
        self, configurationStream: System.IO.Stream
    ) -> bool: ...
    def CloseFile(self) -> None: ...
    def AddInstrumentTrace(
        self,
        traceId: str,
        deviceName: str,
        deviceNumber: str,
        channelName: str,
        axisTitleY: str,
        description: str,
        axisMultiplierY: float,
        valuesX: List[float],
        valuesY: List[float],
    ) -> bool: ...
    def CreateSpectra(
        self,
        traceId: str,
        deviceName: str,
        deviceNumber: str,
        spectraDescription: str,
        scaleFactor: float,
        units: str,
    ) -> bool: ...
    def AddToNonEquidistantSignal(
        self, traceId: str, valuesX: List[float], valuesY: List[float]
    ) -> bool: ...

class RawMetadata:  # Class
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(
        self,
        injectionAcquisitionMetadata: Agilent.OpenLab.RawData.InjectionAcquisitionMetadata,
    ) -> None: ...

    InjectionAcquisitionMetadata: Agilent.OpenLab.RawData.InjectionAcquisitionMetadata
    Signals: Dict[str, Agilent.OpenLab.RawData.SignalMetadata]  # readonly

    def ExtendSpectra(
        self,
        traceId: str,
        records: int,
        detectorType: Agilent.OpenLab.RawData.SpectraDetectorType,
    ) -> None: ...
    @staticmethod
    def Load(stream: System.IO.Stream) -> Agilent.OpenLab.RawData.RawMetadata: ...
    def AddSignal(
        self,
        traceId: str,
        deviceName: str,
        deviceNumber: str,
        channelName: str,
        signalDescription: str,
        startTime: float,
        endTime: float,
        minSignal: float,
        maxSignal: float,
        slope: float,
        units: str,
        isIntegrable: bool,
        numberOfValues: int,
    ) -> None: ...
    def ExtendInstrumentTrace(
        self,
        traceId: str,
        startTime: Optional[float],
        endTime: float,
        numberOfValues: int,
    ) -> None: ...
    def AddNonEquidistantSignal(
        self,
        traceId: str,
        deviceName: str,
        deviceNumber: str,
        channelName: str,
        signalDescription: str,
        slope: float,
        units: str,
        isIntegrable: bool,
        numberOfValues: int = ...,
    ) -> None: ...
    def AddSpectra(
        self,
        traceId: str,
        deviceName: str,
        deviceNumber: str,
        spectraDescription: str,
        detectorType: Agilent.OpenLab.RawData.SpectraDetectorType,
        scaleFactor: float,
        units: str,
        records: int,
    ) -> None: ...
    def ExtendNonEquidistantSignal(
        self,
        traceId: str,
        startTime: Optional[float],
        endTime: float,
        numberOfValues: int,
    ) -> None: ...
    def AddGenericResults(
        self,
        traceId: str,
        moduleId: str,
        serialNumber: str,
        dataChannelId: str,
        dataChannelName: str,
        dataChannelDescription: str,
        dataContentId: str,
        dataContentSequenceNumber: str,
        dataContentType: str,
    ) -> None: ...
    def AddInstrumentTrace(
        self,
        traceId: str,
        deviceName: str,
        deviceNumber: str,
        channelName: str,
        signalDescription: str,
        slope: float,
        units: str,
        numberOfValues: int = ...,
    ) -> None: ...
    def ExtendSignal(
        self,
        traceId: str,
        startTime: Optional[float],
        endTime: float,
        minSignal: float,
        maxSignal: float,
        numberOfValues: int,
    ) -> None: ...
    def AddMsData(
        self,
        name: str,
        description: str,
        startTime: float,
        endTime: float,
        externalElementPaths: str,
    ) -> None: ...
    @overload
    def GetSignalMetadata(
        self, traceId: str
    ) -> Agilent.OpenLab.RawData.SignalMetadata: ...
    @overload
    def GetSignalMetadata(
        self, typeOfSignal: Agilent.OpenLab.RawData.SignalType
    ) -> Agilent.OpenLab.RawData.SignalMetadata: ...
    def Save(self, stream: System.IO.Stream) -> None: ...

class SignalData(Agilent.OpenLab.RawData.HeaderData):  # Class
    def __init__(self) -> None: ...

    SignalInfo: Agilent.OpenLab.RawData.SignalInformation2D
    UnicodeFileHeader2D: Agilent.OpenLab.RawData.UnicodeFileHeader2D
    XValues: List[float]
    YValues: List[float]

    def Write2DSignal(self, binWriter: Agilent.OpenLab.RawData.BinWriter) -> bool: ...
    def Extend2DSignal(self, binWriter: Agilent.OpenLab.RawData.BinWriter) -> bool: ...
    @staticmethod
    def ReadLegacyMetadata(
        binReader: Agilent.OpenLab.RawData.BinReader,
    ) -> Agilent.OpenLab.RawData.RawDataLegacyMetadata: ...
    @staticmethod
    def Read2DSignal(
        binReader: Agilent.OpenLab.RawData.BinReader, numberOfValues: int
    ) -> Agilent.OpenLab.RawData.SignalData: ...

class SignalInformation2D:  # Class
    def __init__(self) -> None: ...

    BunchPower1: int
    BunchPower2: int
    Detector1: int
    Detector2: int
    HeaderSize: int
    HeaderVersion: int
    Intercept: float
    Max1: float
    Max2: int
    Method1: int
    Method2: int
    Min1: float
    Min2: int
    PeakWidth1: float
    PeakWidth2: float
    Present1: int
    Present2: int
    SignalDataType: int
    SignalDescription: str
    Slope: float
    Units: str
    Version1: int
    Version2: int
    WordAlign1: int
    WordAlign2: int
    Zero1: float
    Zero2: int

class SignalMetadata:  # Class
    def __init__(self) -> None: ...

    ChannelName: str
    DataChannelDescription: str
    DataChannelId: str
    DataChannelName: str
    DataContentId: str
    DataContentSequenceNumber: str
    DataContentType: str
    Description: str
    DetectorType: Agilent.OpenLab.RawData.SpectraDetectorType
    DeviceName: str
    DeviceNumber: str
    EndTime: float
    ExternalElementPaths: str
    IsIntegrable: bool
    Max: float
    Min: float
    NumberOfRecords: int
    NumberOfValues: int
    ScaleFactor: float
    Slope: float
    StartTime: float
    TraceId: str
    TypeOfSignal: Agilent.OpenLab.RawData.SignalType  # readonly
    Units: str

class SignalType(
    System.IConvertible, System.IComparable, System.IFormattable
):  # Struct
    GenericAnalyticalResults: Agilent.OpenLab.RawData.SignalType = (
        ...
    )  # static # readonly
    InstrumentTrace: Agilent.OpenLab.RawData.SignalType = ...  # static # readonly
    MS: Agilent.OpenLab.RawData.SignalType = ...  # static # readonly
    Signal2D: Agilent.OpenLab.RawData.SignalType = ...  # static # readonly
    SignalNonEquidistant2D: Agilent.OpenLab.RawData.SignalType = (
        ...
    )  # static # readonly
    Spectra3D: Agilent.OpenLab.RawData.SignalType = ...  # static # readonly
    Undefined: Agilent.OpenLab.RawData.SignalType = ...  # static # readonly

class SpectraData(Agilent.OpenLab.RawData.HeaderData):  # Class
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(
        self,
        location: str,
        sequenceLine: int,
        replicate: int,
        sampleName: str,
        runOperator: str,
        barcode: str,
        runDateTime: System.DateTime,
        acquisitionMethod: str,
        scaleFactor: float,
        units: str,
        detectorType: Agilent.OpenLab.RawData.SpectraDetectorType,
    ) -> None: ...
    @overload
    def __init__(
        self,
        totalRecords: int,
        scaleFactor: float,
        detectorType: Agilent.OpenLab.RawData.SpectraDetectorType,
        newRecords: int,
    ) -> None: ...

    UnicodeFileHeader3D: Agilent.OpenLab.RawData.UnicodeFileHeader3D

class SpectraDetectorType(
    System.IConvertible, System.IComparable, System.IFormattable
):  # Struct
    Dad: Agilent.OpenLab.RawData.SpectraDetectorType = ...  # static # readonly
    Fld: Agilent.OpenLab.RawData.SpectraDetectorType = ...  # static # readonly
    MS: Agilent.OpenLab.RawData.SpectraDetectorType = ...  # static # readonly
    Undefined: Agilent.OpenLab.RawData.SpectraDetectorType = ...  # static # readonly

class SpectrumAttribute(
    System.IConvertible, System.IComparable, System.IFormattable
):  # Struct
    DadCancellationPeak: Agilent.OpenLab.RawData.SpectrumAttribute = (
        ...
    )  # static # readonly
    DadEndPeak: Agilent.OpenLab.RawData.SpectrumAttribute = ...  # static # readonly
    DadInflectionPointDownslopeFalling: Agilent.OpenLab.RawData.SpectrumAttribute = (
        ...
    )  # static # readonly
    DadInflectionPointDownslopeRising: Agilent.OpenLab.RawData.SpectrumAttribute = (
        ...
    )  # static # readonly
    DadInflectionPointUpslopeFalling: Agilent.OpenLab.RawData.SpectrumAttribute = (
        ...
    )  # static # readonly
    DadInflectionPointUpslopeRising: Agilent.OpenLab.RawData.SpectrumAttribute = (
        ...
    )  # static # readonly
    DadManuallyOrTime: Agilent.OpenLab.RawData.SpectrumAttribute = (
        ...
    )  # static # readonly
    DadPeakAll: Agilent.OpenLab.RawData.SpectrumAttribute = ...  # static # readonly
    DadPeakBegin: Agilent.OpenLab.RawData.SpectrumAttribute = ...  # static # readonly
    DadPeriodically: Agilent.OpenLab.RawData.SpectrumAttribute = (
        ...
    )  # static # readonly
    DadSmallPeakTop: Agilent.OpenLab.RawData.SpectrumAttribute = (
        ...
    )  # static # readonly
    DadTopPeak: Agilent.OpenLab.RawData.SpectrumAttribute = ...  # static # readonly
    DadValley: Agilent.OpenLab.RawData.SpectrumAttribute = ...  # static # readonly
    FldEmissionScan: Agilent.OpenLab.RawData.SpectrumAttribute = (
        ...
    )  # static # readonly
    FldExcitationScan: Agilent.OpenLab.RawData.SpectrumAttribute = (
        ...
    )  # static # readonly
    ForceBaseline: Agilent.OpenLab.RawData.SpectrumAttribute = ...  # static # readonly
    Undefined: Agilent.OpenLab.RawData.SpectrumAttribute = ...  # static # readonly
    Unknown: Agilent.OpenLab.RawData.SpectrumAttribute = ...  # static # readonly

class StandardFileHeader2D:  # Class
    def __init__(self) -> None: ...

    AlsBottle: int
    AlsBottleX: int
    DataOffset: int
    DirEntType: int
    DirOffset: int
    EndTime: float
    ExtraRecords: int
    FileType: int
    FileTypeDefinition: str  # readonly
    MaxSignal: float
    MaxY: float
    MaxZ: int
    MinSignal: float
    MinY: float
    MinZ: int
    Mode: int
    NormOffset: int
    NumRecords: int
    Replicate: int
    RunTableOffset: int
    SeqIndex: int
    StartTime: Optional[float]

class TimeUnitType(
    System.IConvertible, System.IComparable, System.IFormattable
):  # Struct
    Milliseconds: Agilent.OpenLab.RawData.TimeUnitType = ...  # static # readonly
    Seconds: Agilent.OpenLab.RawData.TimeUnitType = ...  # static # readonly
    Undefined: Agilent.OpenLab.RawData.TimeUnitType = ...  # static # readonly

class UnicodeFileHeader2D:  # Class
    def __init__(self) -> None: ...

    Barcode: str
    DateTime: str
    File: str
    FileNum: str
    HeaderSize: int
    HeaderVersion: int
    Inlet: str
    InstModel: str
    MethodFile: str
    Operator: str
    SampleLocation: str
    SampleName: str

class UnicodeFileHeader3D(Agilent.OpenLab.RawData.UnicodeFileHeader2D):  # Class
    def __init__(self) -> None: ...

    Detector: Agilent.OpenLab.RawData.SpectraDetectorType
    MiscInfo: str
    ScaleFactor: float
    Units: str

class Writer2DCreateInfo(
    Agilent.OpenLab.RawData.IWriterCreateInfo,
    Agilent.OpenLab.RawData.IWriter2DCreateInfo,
):  # Class
    @overload
    def __init__(
        self,
        traceId: str,
        deviceName: str,
        deviceNumber: str,
        channelName: str,
        sampleFrequency: float,
        signalUnits: str,
        signalDescription: str,
        slope: float,
        isIntegrable: bool,
    ) -> None: ...
    @overload
    def __init__(self) -> None: ...

    ChannelName: str
    Description: str
    DeviceName: str
    DeviceNumber: str
    IsIntegrable: bool
    SampleFrequency: float
    SignalDescription: str
    SignalUnits: str
    Slope: float
    TraceId: str

class Writer3DCreateInfo(
    Agilent.OpenLab.RawData.IWriter3DCreateInfo,
    Agilent.OpenLab.RawData.IWriterCreateInfo,
):  # Class
    @overload
    def __init__(
        self,
        traceId: str,
        deviceName: str,
        deviceNumber: str,
        spectraDescription: str,
        scaleFactor: float,
        units: str,
    ) -> None: ...
    @overload
    def __init__(self) -> None: ...

    Description: str
    DeviceName: str
    DeviceNumber: str
    ScaleFactor: float
    SpectraDescription: str
    TraceId: str
    Units: str

class WriterAdd2DDataInfo(
    Agilent.OpenLab.RawData.IWriterAdd2DDataInfo,
    Agilent.OpenLab.RawData.IWriterAddDataInfo,
):  # Class
    @overload
    def __init__(
        self,
        traceId: str,
        startTime: Optional[float],
        endTime: float,
        yValues: List[float],
    ) -> None: ...
    @overload
    def __init__(self) -> None: ...

    Description: str
    EndTime: float
    StartTime: Optional[float]
    TraceId: str
    YValues: List[float]

class WriterAdd3DDataInfo(
    Agilent.OpenLab.RawData.IWriterAddDataInfo,
    Agilent.OpenLab.RawData.IWriterAdd3DDataInfo,
):  # Class
    @overload
    def __init__(
        self,
        traceId: str,
        detectorType: Agilent.OpenLab.RawData.SpectraDetectorType,
        spectrumRecords: System.Collections.Generic.List[
            Agilent.OpenLab.RawData.LCSpectrum
        ],
    ) -> None: ...
    @overload
    def __init__(self) -> None: ...

    Description: str
    DetectorType: Agilent.OpenLab.RawData.SpectraDetectorType
    SpectrumRecords: System.Collections.Generic.List[Agilent.OpenLab.RawData.LCSpectrum]
    TraceId: str

class WriterAddMsDataInfo(
    Agilent.OpenLab.RawData.IWriterAddMsDataInfo,
    Agilent.OpenLab.RawData.IWriterAddDataInfo,
):  # Class
    def __init__(self) -> None: ...

    Description: str
    IsEndOfData: bool
    ScansData: List[Agilent.OpenLab.RawData.MassSpecScan]
    TraceId: str

class WriterMsCreateInfo(
    Agilent.OpenLab.RawData.IWriterCreateInfo,
    Agilent.OpenLab.RawData.IWriterMsCreateInfo,
):  # Class
    @overload
    def __init__(
        self,
        traceId: str,
        msScanBinStream: System.IO.Stream,
        msPeakBinStream: System.IO.Stream,
        msProfileBinStream: System.IO.Stream,
        msMassCalBinStream: System.IO.Stream,
        msInitializationInfo: str,
        contents: Agilent.MassSpectrometry.DataAnalysis.Contents,
        device: Agilent.MassSpectrometry.DataAnalysis.Device,
    ) -> None: ...
    @overload
    def __init__(self) -> None: ...

    Contents: Agilent.MassSpectrometry.DataAnalysis.Contents
    Description: str
    Device: Agilent.MassSpectrometry.DataAnalysis.Device
    MsInitializationInfo: str
    MsMassCalBinStream: System.IO.Stream
    MsPeakBinStream: System.IO.Stream
    MsProfileBinStream: System.IO.Stream
    MsScanBinStream: System.IO.Stream
    TraceId: str

class XUnitType(System.IConvertible, System.IComparable, System.IFormattable):  # Struct
    Milliseconds: Agilent.OpenLab.RawData.XUnitType = ...  # static # readonly
    Nanometer: Agilent.OpenLab.RawData.XUnitType = ...  # static # readonly
    Seconds: Agilent.OpenLab.RawData.XUnitType = ...  # static # readonly
    Undefined: Agilent.OpenLab.RawData.XUnitType = ...  # static # readonly



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

from .ScriptIF import IUIState

# Stubs for namespace: Agilent.MassHunter.Quantitative.DynamicCalibrationSetup.Tools

class FileToolHandler(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IToolHandler
):  # Class
    def __init__(self) -> None: ...
    def Execute(
        self,
        toolState: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IToolState,
        objUiState: Any,
    ) -> None: ...
    def SetState(
        self,
        toolState: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IToolState,
        objUiState: Any,
    ) -> None: ...

class ToolHandlerIonGroupsView(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IToolHandler
):  # Class
    def __init__(self) -> None: ...
    def Execute(
        self,
        toolState: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IToolState,
        objUiState: Any,
    ) -> None: ...
    def SetState(
        self,
        toolState: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IToolState,
        objUiState: Any,
    ) -> None: ...

class ToolHandlerMethod(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IToolHandler
):  # Class
    def __init__(self) -> None: ...
    def Execute(
        self,
        toolState: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IToolState,
        objUiState: Any,
    ) -> None: ...
    def SetState(
        self,
        toolState: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IToolState,
        objUiState: Any,
    ) -> None: ...

class ToolManager(
    Agilent.MassHunter.Quantitative.ToolbarWPF.ToolManager.IToolManager,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar2.IToolManager,
    System.IDisposable,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IToolbarsManager,
    Agilent.MassHunter.Quantitative.ToolbarWPF.ToolManager.ToolManagerBase,
):  # Class
    def __init__(
        self, ribbon: Infragistics.Windows.Ribbon.XamRibbon, uiState: IUIState
    ) -> None: ...

    _UIState: IUIState  # readonly

    def RegisterScriptToolHandler(
        self, id: str, module: str, setState: str, execute: str
    ) -> None: ...
    def ApplicationMenu2010SelectedTabItemChanged(self) -> None: ...
    def GetApplicationMenu2010Content(self, category: str, id: str) -> Any: ...
    def ApplicationMenu2010Closed(self) -> None: ...
    def RegisterScriptCategoryHandler(
        self, category: str, module: str, setState: str, execute: str
    ) -> None: ...
    def GetToolCaption(self, id: str) -> str: ...
